# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/IssuingAttributes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&sharepubapi_v1/IssuingAttributes.proto\x12\x18yoti.core.sharepubapi_v1\"c\n\x11IssuingAttributes\x12\x13\n\x0b\x65xpiry_date\x18\x01 \x01(\t\x12\x39\n\x0b\x64\x65\x66initions\x18\x02 \x03(\x0b\x32$.yoti.core.sharepubapi_v1.Definition\"\x1a\n\nDefinition\x12\x0c\n\x04name\x18\x01 \x01(\tBr\n\x17\x63om.yoti.sharepubapi_v1B\x16IssuingAttributesProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IssuingAttributes_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\026IssuingAttributesProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _ISSUINGATTRIBUTES._serialized_start=68
  _ISSUINGATTRIBUTES._serialized_end=167
  _DEFINITION._serialized_start=169
  _DEFINITION._serialized_end=195
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import json
from yoti_python_sdk import client

INVALID_DATA = "Json is incorrect, contains invalid data"
APPLICATION_NOT_FOUND = "Application was not found"
UNKNOWN_ERROR = "Unknown HTTP error occurred"


SHARE_URL_ERRORS = {
    400: "Json is incorrect, contains invalid data",
    404: "Application was not found",
}
SHARE_URL_ERRORS.update(client.DEFAULT_HTTP_CLIENT_ERRORS)


def create_share_url(yoti_client, dynamic_scenario):
    http_method = "POST"
    payload = json.dumps(dynamic_scenario, sort_keys=True).encode()
    endpoint = yoti_client.endpoints.get_dynamic_share_request_url(no_params=True)
    response = yoti_client.make_request(http_method, endpoint, payload)

    client.Client.http_error_handler(response, SHARE_URL_ERRORS)

    response_json = json.loads(response.text)

    return ShareUrl(
        _ShareUrl__qr_code=response_json["qrcode"],
        _ShareUrl__ref_id=response_json["ref_id"],
    )


class ShareUrl(object):
    def __init__(self, **kwargs):
        self.__dict__.update(kwargs)

    @property
    def share_url(self):
        return self.__qr_code

    @property
    def ref_id(self):
        return self.__ref_id



from yoti_python_sdk.exceptions import MalformedAgeVerificationException
from yoti_python_sdk import config


class AgeVerification(object):
    def __init__(self, derived_attribute):
        self.__derived_attribute = derived_attribute

        split = derived_attribute.name.split(":")
        if len(split) != 2:
            raise MalformedAgeVerificationException

        if (
            split[0] in config.ATTRIBUTE_AGE_OVER
            or split[0] in config.ATTRIBUTE_AGE_UNDER
        ):
            self.__check_type = split[0]
        else:
            raise MalformedAgeVerificationException

        try:
            self.__age_verified = int(split[1])
            if derived_attribute.value == "true":
                self.__result = True
            elif derived_attribute.value == "false":
                self.__result = False
        except Exception:
            raise MalformedAgeVerificationException

    @property
    def age(self):
        return self.__age_verified

    @property
    def check_type(self):
        return self.__check_type

    @property
    def result(self):
        return self.__result

    @property
    def attribute(self):
        return self.__derived_attribute



from yoti_python_sdk.doc_scan.constants import SUPPLEMENTARY_DOCUMENT
from yoti_python_sdk.utils import remove_null_values
from .required_document import RequiredDocument


class RequiredSupplementaryDocument(RequiredDocument):
    def __init__(self, objective, document_types=None, country_codes=None):
        """
        :param objective: the objective for the document
        :type objective: Objective
        :param document_types: the document types
        :type document_types: list[str]
        :param country_codes: the country codes
        :type country_codes: list[str]
        """
        self.__objective = objective
        self.__document_types = document_types
        self.__country_codes = country_codes

    @property
    def type(self):
        return SUPPLEMENTARY_DOCUMENT

    def to_json(self):
        return remove_null_values(
            {
                "type": self.type,
                "objective": self.__objective,
                "document_types": self.__document_types,
                "country_codes": self.__country_codes,
            }
        )


class RequiredSupplementaryDocumentBuilder(object):
    """
    Builder used to assist the creation of a required supplementary document.
    """

    def __init__(self):
        self.__objective = None
        self.__document_types = None
        self.__country_codes = None

    def with_objective(self, objective):
        """
        Sets the supplementary document objective

        :param objective: the objective
        :type objective: Objective
        :return: the builder
        :rtype: RequiredSupplementaryDocumentBuilder
        """
        self.__objective = objective
        return self

    def with_document_types(self, document_types):
        """
        Sets the supplementary document types

        :param document_types: the document types
        :type document_types: list[str]
        :return: the builder
        :rtype: RequiredSupplementaryDocumentBuilder
        """
        self.__document_types = document_types
        return self

    def with_country_codes(self, country_codes):
        """
        Sets the supplementary document country codes

        :param country_codes: the country codes
        :type country_codes: list[str]
        :return: the builder
        :rtype: RequiredSupplementaryDocumentBuilder
        """
        self.__country_codes = country_codes
        return self

    def build(self):
        """
        Builds a required supplementary document, using the values supplied to the builder

        :return: the required supplementary document
        :rtype: RequiredSupplementaryDocument
        """
        return RequiredSupplementaryDocument(
            self.__objective, self.__document_types, self.__country_codes
        )



from yoti_python_sdk.utils import create_timestamp, create_nonce


class Endpoint(object):
    def __init__(self, sdk_id):
        self.sdk_id = sdk_id

    def get_activity_details_request_path(
        self, decrypted_request_token, no_params=False
    ):
        if no_params:
            return "/profile/{0}".format(decrypted_request_token)

        return "/profile/{0}?nonce={1}&timestamp={2}&appId={3}".format(
            decrypted_request_token, create_nonce(), create_timestamp(), self.sdk_id
        )

    def get_aml_request_url(self, no_params=False):
        if no_params:
            return "/aml-check"

        return "/aml-check?appId={0}&timestamp={1}&nonce={2}".format(
            self.sdk_id, create_timestamp(), create_nonce()
        )

    def get_dynamic_share_request_url(self, no_params=False):
        if no_params:
            return "/qrcodes/apps/{appid}".format(appid=self.sdk_id)

        return "/qrcodes/apps/{appid}?nonce={nonce}&timestamp={timestamp}".format(
            appid=self.sdk_id, nonce=create_nonce(), timestamp=create_timestamp()
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/UserProfile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Address_pb2 as compubapi__v1_dot_Address__pb2
from . import IdentityProfile_pb2 as compubapi__v1_dot_IdentityProfile__pb2
from . import DocumentFields_pb2 as compubapi__v1_dot_DocumentFields__pb2
from . import DocumentTypes_pb2 as compubapi__v1_dot_DocumentTypes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ompubapi_v1/UserProfile.proto\x12\x16yoti.core.compubapi_v1\x1a\x1a\x63ompubapi_v1/Address.proto\x1a\"compubapi_v1/IdentityProfile.proto\x1a!compubapi_v1/DocumentFields.proto\x1a compubapi_v1/DocumentTypes.proto\"\xbc\x01\n\x0bUserProfile\x12\x45\n\x12identity_assertion\x18\x01 \x01(\x0b\x32).yoti.core.compubapi_v1.IdentityAssertion\x12!\n\x19\x65vidence_collection_db_id\x18\x02 \x01(\x0c\x12\x43\n\x11unlinked_evidence\x18\x03 \x03(\x0b\x32(.yoti.core.compubapi_v1.UnlinkedEvidence\"\xc2\x02\n\x11IdentityAssertion\x12\x32\n\x0c\x63urrent_name\x18\x01 \x01(\x0b\x32\x1c.yoti.core.compubapi_v1.Name\x12:\n\rdate_of_birth\x18\x02 \x01(\x0b\x32#.yoti.core.compubapi_v1.DateOfBirth\x12\x41\n\x0f\x63urrent_address\x18\x03 \x01(\x0b\x32(.yoti.core.compubapi_v1.AddressWithDates\x12\x44\n\x12previous_addresses\x18\x04 \x03(\x0b\x32(.yoti.core.compubapi_v1.AddressWithDates\x12\x34\n\x0eprevious_names\x18\x05 \x03(\x0b\x32\x1c.yoti.core.compubapi_v1.Name\"\x82\x03\n\x10\x41\x64\x64ressWithDates\x12\x38\n\x0fprofile_address\x18\x01 \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Address\x12\x0f\n\x07move_in\x18\x02 \x01(\t\x12\x10\n\x08move_out\x18\x03 \x01(\t\x12<\n\x0e\x65vidence_links\x18\x04 \x03(\x0b\x32$.yoti.core.compubapi_v1.EvidenceLink\x12<\n\x08\x61\x64\x64\x65\x64_at\x18\x07 \x01(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12@\n\x0c\x63onfirmed_at\x18\x08 \x01(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12\x41\n\rconfirmations\x18\t \x03(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestampJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\n\x10\x0b\"\xac\x01\n\x12\x41ssertionTimestamp\x12\n\n\x02ts\x18\x01 \x01(\t\x12\x41\n\x06source\x18\x02 \x01(\x0e\x32\x31.yoti.core.compubapi_v1.AssertionTimestamp.Source\"G\n\x06Source\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08\x44OCUMENT\x10\x01\x12\n\n\x06MANUAL\x10\x02\x12\x14\n\x10RELYING_BUSINESS\x10\x03\"\xd3\x02\n\x12\x43onfirmationStatus\x12\x41\n\x06source\x18\x01 \x01(\x0e\x32\x31.yoti.core.compubapi_v1.ConfirmationStatus.Source\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.yoti.core.compubapi_v1.ConfirmationStatus.Status\";\n\x06Source\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08\x45ND_USER\x10\x01\x12\x14\n\x10RELYING_BUSINESS\x10\x02\"g\n\x06Status\x12\x1a\n\x16NO_MANUAL_CONFIRMATION\x10\x00\x12!\n\x1dMANUAL_CONFIRMATION_SUCCEEDED\x10\x01\x12\x1e\n\x1aMANUAL_CONFIRMATION_FAILED\x10\x02\"\xef\x02\n\x04Name\x12\x34\n\x04name\x18\x01 \x01(\x0b\x32&.yoti.core.compubapi_v1.StructuredName\x12\x11\n\theld_from\x18\x02 \x01(\t\x12\x0f\n\x07held_to\x18\x03 \x01(\t\x12<\n\x0e\x65vidence_links\x18\x04 \x03(\x0b\x32$.yoti.core.compubapi_v1.EvidenceLink\x12<\n\x08\x61\x64\x64\x65\x64_at\x18\x05 \x01(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12\x41\n\rconfirmations\x18\x06 \x03(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12N\n\x1amanual_confirmation_status\x18\x07 \x01(\x0b\x32*.yoti.core.compubapi_v1.ConfirmationStatus\"\xb3\x02\n\x0b\x44\x61teOfBirth\x12\x15\n\rdate_of_birth\x18\x01 \x01(\t\x12<\n\x0e\x65vidence_links\x18\x02 \x03(\x0b\x32$.yoti.core.compubapi_v1.EvidenceLink\x12<\n\x08\x61\x64\x64\x65\x64_at\x18\x03 \x01(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12\x41\n\rconfirmations\x18\x04 \x03(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12N\n\x1amanual_confirmation_status\x18\x05 \x01(\x0b\x32*.yoti.core.compubapi_v1.ConfirmationStatus\"v\n\x0eStructuredName\x12\x13\n\x0bgiven_names\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x13\n\x0bmiddle_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x11\n\tfull_name\x18\x05 \x01(\t\"#\n\x0c\x45videnceLink\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\"\xda\x01\n\x12\x45videnceCollection\x12\x39\n\x04\x66\x61\x63\x65\x18\x01 \x01(\x0b\x32+.yoti.core.compubapi_v1.FaceCaptureEvidence\x12;\n\tdocuments\x18\x02 \x03(\x0b\x32(.yoti.core.compubapi_v1.DocumentEvidence\x12L\n\x12\x65lectronic_records\x18\x03 \x03(\x0b\x32\x30.yoti.core.compubapi_v1.ElectronicRecordEvidence\"\xd7\x02\n\x13\x46\x61\x63\x65\x43\x61ptureEvidence\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x36\n\x0b\x61udit_links\x18\x02 \x03(\x0b\x32!.yoti.core.compubapi_v1.AuditLink\x12@\n\x10initial_liveness\x18\x03 \x01(\x0b\x32&.yoti.core.compubapi_v1.PassedLiveness\x12\x45\n\x15last_matched_liveness\x18\x04 \x01(\x0b\x32&.yoti.core.compubapi_v1.PassedLiveness\x12\x36\n\x06source\x18\x05 \x01(\x0b\x32&.yoti.core.compubapi_v1.EvidenceSource\x12\x15\n\rverifying_org\x18\x06 \x01(\t\x12\x1b\n\x13selfie_attribute_id\x18\x07 \x01(\x0c\"\xe0\x03\n\x10\x44ocumentEvidence\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x36\n\x0b\x61udit_links\x18\x03 \x03(\x0b\x32!.yoti.core.compubapi_v1.AuditLink\x12\x39\n\rdocument_info\x18\x04 \x01(\x0b\x32\".yoti.core.compubapi_v1.IdDocument\x12?\n\x0f\x64ocument_fields\x18\x05 \x01(\x0b\x32&.yoti.core.compubapi_v1.DocumentFields\x12<\n\rpassed_checks\x18\x06 \x03(\x0b\x32%.yoti.core.compubapi_v1.DocumentCheck\x12$\n\x1c\x64ocument_images_attribute_id\x18\x07 \x01(\x0c\x12\x36\n\x06source\x18\x08 \x01(\x0b\x32&.yoti.core.compubapi_v1.EvidenceSource\x12\x15\n\rverifying_org\x18\t \x01(\t\x12=\n\x0eimport_details\x18\n \x01(\x0b\x32%.yoti.core.compubapi_v1.ImportDetails\"\xb8\x02\n\x18\x45lectronicRecordEvidence\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x36\n\x0b\x61udit_links\x18\x03 \x03(\x0b\x32!.yoti.core.compubapi_v1.AuditLink\x12\x41\n\x10identity_details\x18\x04 \x01(\x0b\x32\'.yoti.core.compubapi_v1.IdentityDetails\x12\x15\n\rverifying_org\x18\x05 \x01(\t\x12\x14\n\x0cprovider_org\x18\x06 \x01(\t\x12L\n\x16identity_check_outcome\x18\x07 \x01(\x0b\x32,.yoti.core.compubapi_v1.IdentityCheckOutcome\"\xcc\x02\n\x14IdentityCheckOutcome\x12?\n\x04type\x18\x01 \x01(\x0e\x32\x31.yoti.core.compubapi_v1.IdentityCheckOutcome.Type\x12;\n\rcifas_outcome\x18\x02 \x01(\x0b\x32$.yoti.core.compubapi_v1.CIFASOutcome\x12\x37\n\x0b\x63ra_outcome\x18\x03 \x01(\x0b\x32\".yoti.core.compubapi_v1.CRAOutcome\x12\x43\n\x11synectics_outcome\x18\x04 \x01(\x0b\x32(.yoti.core.compubapi_v1.SynecticsOutcome\"8\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05\x43IFAS\x10\x01\x12\x07\n\x03\x43RA\x10\x02\x12\r\n\tSYNECTICS\x10\x03\"\xa0\x01\n\x0c\x43IFASOutcome\x12\x39\n\x05state\x18\x01 \x01(\x0e\x32*.yoti.core.compubapi_v1.CIFASOutcome.State\"U\n\x05State\x12\r\n\tUNDEFINED\x10\x00\x12\x11\n\rNOT_FRAUDSTER\x10\x01\x12\r\n\tFRAUDSTER\x10\x02\x12\x10\n\x0c\x46RAUD_VICTIM\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"\xbd\x04\n\nCRAOutcome\x12?\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0e\x32..yoti.core.compubapi_v1.CRAOutcome.MatchResult\x12<\n\x04name\x18\x02 \x01(\x0e\x32..yoti.core.compubapi_v1.CRAOutcome.MatchResult\x12;\n\x03\x64ob\x18\x03 \x01(\x0e\x32..yoti.core.compubapi_v1.CRAOutcome.MatchResult\x12G\n\x0bpep_warning\x18\x04 \x01(\x0e\x32\x32.yoti.core.compubapi_v1.CRAOutcome.AdditionalCheck\x12\x44\n\x08\x64\x65\x63\x65\x61sed\x18\x05 \x01(\x0e\x32\x32.yoti.core.compubapi_v1.CRAOutcome.AdditionalCheck\x12J\n\x0e\x65lectoral_roll\x18\x06 \x01(\x0e\x32\x32.yoti.core.compubapi_v1.CRAOutcome.AdditionalCheck\x12\x19\n\x11unable_to_perform\x18\x07 \x01(\x08\">\n\x0bMatchResult\x12\x11\n\rNOT_AVAILABLE\x10\x00\x12\x0b\n\x07MATCHED\x10\x01\x12\x0f\n\x0bNOT_MATCHED\x10\x02\"=\n\x0f\x41\x64\x64itionalCheck\x12\x12\n\x0eNOT_APPLICABLE\x10\x00\x12\n\n\x06PASSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"v\n\x10SynecticsOutcome\x12\x18\n\x10\x61\x63tivity_history\x18\x01 \x01(\x05\x12\x16\n\x0eidentity_fraud\x18\x02 \x01(\x05\x12\x15\n\rfailed_checks\x18\x03 \x03(\t\x12\x19\n\x11unable_to_perform\x18\x04 \x01(\x08\"\xa8\x01\n\x0ePassedLiveness\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.yoti.core.compubapi_v1.PassedLiveness.Type\x12\x11\n\ttimestamp\x18\x02 \x01(\t\"H\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04ZOOM\x10\x01\x12\n\n\x06STATIC\x10\x02\x12\x0f\n\x0bTHREE_WORDS\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\"\xae\x01\n\tAuditLink\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.yoti.core.compubapi_v1.AuditLink.Type\x12\n\n\x02id\x18\x02 \x01(\t\"_\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12!\n\x1d\x44ID_USER_ACTIVITY_TRACKING_ID\x10\x01\x12\x10\n\x0cIDV_CHECK_ID\x10\x02\x12\x13\n\x0fIDV_RESOURCE_ID\x10\x03\"\x95\x01\n\x0e\x45videnceSource\x12=\n\x06source\x18\x01 \x01(\x0e\x32-.yoti.core.compubapi_v1.EvidenceSource.Source\"D\n\x06Source\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07IDV_WEB\x10\x01\x12\x11\n\rIDV_WEB_SICAP\x10\x02\x12\x0b\n\x07\x44ID_APP\x10\x03\"\xfb\x02\n\rDocumentCheck\x12:\n\x05\x63heck\x18\x01 \x01(\x0e\x32+.yoti.core.compubapi_v1.DocumentCheck.Check\"\xad\x02\n\x05\x43heck\x12\r\n\tUNDEFINED\x10\x00\x12\'\n#MANUAL_VISUAL_DOCUMENT_AUTHENTICITY\x10\x01\x12\x1a\n\x16\x43HIP_DIGITAL_SIGNATURE\x10\x02\x12\x15\n\x11ISSUING_AUTHORITY\x10\x03\x12\x14\n\x10\x44OCUMENT_IN_DATE\x10\x04\x12\x18\n\x14\x46RAUD_DOCUMENTS_LIST\x10\x05\x12\x15\n\x11MANUAL_FACE_MATCH\x10\x06\x12\x18\n\x14\x41UTOMATED_FACE_MATCH\x10\x07\x12)\n%AUTOMATED_FACE_MATCH_HIGHER_THRESHOLD\x10\x08\x12-\n)HIGH_ASSURANCE_AUTO_DOCUMENT_AUTHENTICITY\x10\t\"4\n\rImportDetails\x12\x13\n\x0bimported_at\x18\x01 \x01(\t\x12\x0e\n\x06org_id\x18\x02 \x01(\t\"\xbd\x01\n\x10UnlinkedEvidence\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12?\n\x06reason\x18\x02 \x01(\x0e\x32/.yoti.core.compubapi_v1.UnlinkedEvidence.Reason\"S\n\x06Reason\x12\r\n\tUNDEFINED\x10\x00\x12\x11\n\rNAME_MISMATCH\x10\x01\x12\x10\n\x0c\x44OB_MISMATCH\x10\x02\x12\x15\n\x11NAME_DOB_MISMATCH\x10\x03\x42\x66\n\x15\x63om.yoti.compubapi_v1B\x10UserProfileProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserProfile_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\020UserProfileProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _USERPROFILE._serialized_start=192
  _USERPROFILE._serialized_end=380
  _IDENTITYASSERTION._serialized_start=383
  _IDENTITYASSERTION._serialized_end=705
  _ADDRESSWITHDATES._serialized_start=708
  _ADDRESSWITHDATES._serialized_end=1094
  _ASSERTIONTIMESTAMP._serialized_start=1097
  _ASSERTIONTIMESTAMP._serialized_end=1269
  _ASSERTIONTIMESTAMP_SOURCE._serialized_start=1198
  _ASSERTIONTIMESTAMP_SOURCE._serialized_end=1269
  _CONFIRMATIONSTATUS._serialized_start=1272
  _CONFIRMATIONSTATUS._serialized_end=1611
  _CONFIRMATIONSTATUS_SOURCE._serialized_start=1447
  _CONFIRMATIONSTATUS_SOURCE._serialized_end=1506
  _CONFIRMATIONSTATUS_STATUS._serialized_start=1508
  _CONFIRMATIONSTATUS_STATUS._serialized_end=1611
  _NAME._serialized_start=1614
  _NAME._serialized_end=1981
  _DATEOFBIRTH._serialized_start=1984
  _DATEOFBIRTH._serialized_end=2291
  _STRUCTUREDNAME._serialized_start=2293
  _STRUCTUREDNAME._serialized_end=2411
  _EVIDENCELINK._serialized_start=2413
  _EVIDENCELINK._serialized_end=2448
  _EVIDENCECOLLECTION._serialized_start=2451
  _EVIDENCECOLLECTION._serialized_end=2669
  _FACECAPTUREEVIDENCE._serialized_start=2672
  _FACECAPTUREEVIDENCE._serialized_end=3015
  _DOCUMENTEVIDENCE._serialized_start=3018
  _DOCUMENTEVIDENCE._serialized_end=3498
  _ELECTRONICRECORDEVIDENCE._serialized_start=3501
  _ELECTRONICRECORDEVIDENCE._serialized_end=3813
  _IDENTITYCHECKOUTCOME._serialized_start=3816
  _IDENTITYCHECKOUTCOME._serialized_end=4148
  _IDENTITYCHECKOUTCOME_TYPE._serialized_start=4092
  _IDENTITYCHECKOUTCOME_TYPE._serialized_end=4148
  _CIFASOUTCOME._serialized_start=4151
  _CIFASOUTCOME._serialized_end=4311
  _CIFASOUTCOME_STATE._serialized_start=4226
  _CIFASOUTCOME_STATE._serialized_end=4311
  _CRAOUTCOME._serialized_start=4314
  _CRAOUTCOME._serialized_end=4887
  _CRAOUTCOME_MATCHRESULT._serialized_start=4762
  _CRAOUTCOME_MATCHRESULT._serialized_end=4824
  _CRAOUTCOME_ADDITIONALCHECK._serialized_start=4826
  _CRAOUTCOME_ADDITIONALCHECK._serialized_end=4887
  _SYNECTICSOUTCOME._serialized_start=4889
  _SYNECTICSOUTCOME._serialized_end=5007
  _PASSEDLIVENESS._serialized_start=5010
  _PASSEDLIVENESS._serialized_end=5178
  _PASSEDLIVENESS_TYPE._serialized_start=5106
  _PASSEDLIVENESS_TYPE._serialized_end=5178
  _AUDITLINK._serialized_start=5181
  _AUDITLINK._serialized_end=5355
  _AUDITLINK_TYPE._serialized_start=5260
  _AUDITLINK_TYPE._serialized_end=5355
  _EVIDENCESOURCE._serialized_start=5358
  _EVIDENCESOURCE._serialized_end=5507
  _EVIDENCESOURCE_SOURCE._serialized_start=5439
  _EVIDENCESOURCE_SOURCE._serialized_end=5507
  _DOCUMENTCHECK._serialized_start=5510
  _DOCUMENTCHECK._serialized_end=5889
  _DOCUMENTCHECK_CHECK._serialized_start=5588
  _DOCUMENTCHECK_CHECK._serialized_end=5889
  _IMPORTDETAILS._serialized_start=5891
  _IMPORTDETAILS._serialized_end=5943
  _UNLINKEDEVIDENCE._serialized_start=5946
  _UNLINKEDEVIDENCE._serialized_end=6135
  _UNLINKEDEVIDENCE_REASON._serialized_start=6052
  _UNLINKEDEVIDENCE_REASON._serialized_end=6135
# @@protoc_insertion_point(module_scope)



from .session.create.check.document_authenticity import (
    RequestedDocumentAuthenticityCheckBuilder,
)
from .session.create.check.document_comparison import (
    RequestedIDDocumentComparisonCheckBuilder,
)
from .session.create.check.face_match import RequestedFaceMatchCheckBuilder
from .session.create.check.liveness import RequestedLivenessCheckBuilder
from .session.create.task.text_extraction import RequestedTextExtractionTaskBuilder
from .session.create.task.supplementary_doc_text_extraction import (
    RequestedSupplementaryDocTextExtractionTaskBuilder,
)
from .session.create.notification_config import NotificationConfigBuilder
from .session.create.sdk_config import SdkConfigBuilder
from .session.create.session_spec import SessionSpecBuilder
from .client import DocScanClient

__all__ = [
    "RequestedDocumentAuthenticityCheckBuilder",
    "RequestedLivenessCheckBuilder",
    "RequestedFaceMatchCheckBuilder",
    "RequestedIDDocumentComparisonCheckBuilder",
    "RequestedTextExtractionTaskBuilder",
    "RequestedSupplementaryDocTextExtractionTaskBuilder",
    "SessionSpecBuilder",
    "NotificationConfigBuilder",
    "SdkConfigBuilder",
    "DocScanClient",
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class GeneratedCheckResponse(object):
    """
    Represents a check response that has been generated by
    the session
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__id = data.get("id", None)
        self.__type = data.get("type", None)

    @property
    def id(self):
        """
        The id of the generated check

        :return: the id
        :rtype: str or None
        """
        return self.__id

    @property
    def type(self):
        """
        Returns the type of the generated check

        :return: the type
        :rtype: str or None
        """
        return self.__type


class GeneratedTextDataCheckResponse(GeneratedCheckResponse):
    """
    Represents a generated Text Data check response
    """

    pass


class GeneratedSupplementaryDocumentTextDataCheckResponse(GeneratedCheckResponse):
    """
    Represents a generated Supplementary Document Text Data check response
    """

    pass



# -*- coding: utf-8 -*-

from yoti_python_sdk.attribute_issuance_details import AttributeIssuanceDetails
from yoti_python_sdk.protobuf.sharepubapi_v1 import ThirdPartyAttribute_pb2
from yoti_python_sdk.protobuf.sharepubapi_v1 import ExtraData_pb2


class ExtraData(object):
    THIRD_PARTY_ATTRIBUTE = 6

    def __init__(self, raw):
        self.__attribute_issuance_details = None
        proto = ExtraData_pb2.ExtraData()
        proto.MergeFromString(raw)
        data_entries_list = proto.list

        for data_entry in data_entries_list:
            if (
                data_entry.type == self.THIRD_PARTY_ATTRIBUTE
                and self.__attribute_issuance_details is None
            ):
                attribute = ThirdPartyAttribute_pb2.ThirdPartyAttribute()
                attribute.MergeFromString(data_entry.value)
                self.__attribute_issuance_details = AttributeIssuanceDetails(attribute)

    @property
    def attribute_issuance_details(self):
        return self.__attribute_issuance_details



# -*- coding: utf-8 -*-
from yoti_python_sdk.protobuf import protobuf


def parse(multi_value_bytes):
    from yoti_python_sdk import (
        attribute_parser,
    )  # needed here (and not above) for Python 2.7 & 3.4 dependency handling

    proto = protobuf.Protobuf()
    multi_value_list = []
    parsed_multi_value = proto.multi_value(multi_value_bytes)

    for multi_value_item in parsed_multi_value.values:
        multi_value_list.append(
            attribute_parser.value_based_on_content_type(
                multi_value_item.data, multi_value_item.content_type
            )
        )

    return multi_value_list


def filter_values(values, type_to_filter):
    return tuple(filter(lambda v: isinstance(v, type_to_filter), values))



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import copy

import pytz


class ThirdPartyAttributeExtension(object):
    THIRDPARTY_ATTRIBUTE = "THIRD_PARTY_ATTRIBUTE"

    def __init__(self):
        self.__extension = {
            "type": self.THIRDPARTY_ATTRIBUTE,
            "content": {"expiry_date": None, "definitions": []},
        }

    def with_expiry_date(self, expiry_date):
        """
        :param expiry_date: Expiry date for the attribute. If no timezone info is provided, UTC will be used.
        :type expiry_date: datetime
        """
        if expiry_date.tzinfo is None:
            expiry_date = expiry_date.replace(tzinfo=pytz.UTC)

        utc_time = expiry_date.astimezone(pytz.utc)
        rfc_3339_milliseconds = utc_time.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3]
        self.__extension["content"]["expiry_date"] = rfc_3339_milliseconds + "Z"
        return self

    def with_definitions(self, *names):
        """
        :param names: attribute definitions
        :type names: str or list[str]
        """
        self.__extension["content"]["definitions"].extend([{"name": s} for s in names])
        return self

    def build(self):
        """
        Builds the object

        :return: the third party attribute
        :rtype: ThirdPartyAttributeExtension
        """
        return copy.deepcopy(self.__extension)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan import constants
from yoti_python_sdk.utils import YotiSerializable, remove_null_values
from .requested_task import RequestedTask


class RequestedTextExtractionTaskConfig(YotiSerializable):
    def __init__(self, manual_check, chip_data=None):
        """
        :param manual_check: the manual check value
        :type manual_check: str
        """
        self.__manual_check = manual_check
        self.__chip_data = chip_data

    @property
    def manual_check(self):
        """
        Describes the manual fallback behaviour applied to each Task

        :return: the manual check value
        """
        return self.__manual_check

    @property
    def chip_data(self):
        """
        Describes how to use chip data from an ID document if
        it is available

        :return: the chip data usage
        """
        return self.__chip_data

    def to_json(self):
        return remove_null_values(
            {"manual_check": self.manual_check, "chip_data": self.chip_data}
        )


class RequestedTextExtractionTask(RequestedTask):
    """
    Builder to assist creation of :class:`RequestedTextExtractionTask`
    """

    def __init__(self, config):
        """
        :param config: the text extraction task configuration
        :type config: RequestedTextExtractionTaskConfig
        """
        self.__config = config

    @property
    def type(self):
        return constants.ID_DOCUMENT_TEXT_DATA_EXTRACTION

    @property
    def config(self):
        return self.__config


class RequestedTextExtractionTaskBuilder(object):
    """
    Builder to assist creation of :class:`RequestedTextExtractionTask`
    """

    def __init__(self):
        self.__manual_check = None
        self.__chip_data = None

    def with_manual_check_always(self):
        """
        Sets the manual check value to be "ALWAYS"

        :return: the builder
        :rtype: RequestedTextExtractionTaskBuilder
        """
        self.__manual_check = constants.ALWAYS
        return self

    def with_manual_check_fallback(self):
        """
        Sets the manual check value to be "FALLBACK"

        :return: the builder
        :rtype: RequestedTextExtractionTaskBuilder
        """
        self.__manual_check = constants.FALLBACK
        return self

    def with_manual_check_never(self):
        """
        Sets the manual check value to be "NEVER"

        :return: the builder
        :rtype: RequestedTextExtractionTaskBuilder
        """
        self.__manual_check = constants.NEVER
        return self

    def with_chip_data_desired(self):
        """
        The TextExtractionTask will use chip data if it is available

        :return: the builder
        :rtype: RequestedTextExtractionTaskBuilder
        """
        self.__chip_data = constants.DESIRED
        return self

    def with_chip_data_ignore(self):
        """
        The TextExtractionTask will ignore chip data

        :return: the builder
        :rtype: RequestedTextExtractionTaskBuilder
        """
        self.__chip_data = constants.IGNORE
        return self

    def build(self):
        config = RequestedTextExtractionTaskConfig(
            self.__manual_check, self.__chip_data
        )
        return RequestedTextExtractionTask(config)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/ReceiptPush.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Sharing_pb2 as sharepubapi__v1_dot_Sharing__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import IdentityProfileReport_pb2 as compubapi__v1_dot_IdentityProfileReport__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n sharepubapi_v1/ReceiptPush.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1csharepubapi_v1/Sharing.proto\x1a(compubapi_v1/IdentityProfileReport.proto\"\x9f\x03\n\x0eSuccessReceipt\x12\x12\n\nreceipt_id\x18\x01 \x01(\x0c\x12\x1f\n\x17other_party_profile_uri\x18\x02 \x01(\t\x12\x13\n\x0bprofile_uri\x18\x03 \x01(\t\x12\"\n\x1aother_party_extra_data_uri\x18\x04 \x01(\t\x12\x16\n\x0e\x65xtra_data_uri\x18\x05 \x01(\t\x12\x13\n\x0breceipt_key\x18\x06 \x01(\x0c\x12\x12\n\npolicy_uri\x18\x07 \x01(\t\x12\x14\n\x0cpersonal_key\x18\x08 \x01(\x0c\x12\x16\n\x0eremember_me_id\x18\t \x01(\x0c\x12\x11\n\ttimestamp\x18\n \x01(\t\x12\x14\n\x0csession_data\x18\x0b \x01(\t\x12\x30\n\x06issuer\x18\x0c \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\r \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12\x1d\n\x15parent_remember_me_id\x18\x0e \x01(\x0c\"\x93\x02\n\x0e\x46\x61ilureReceipt\x12\x12\n\nreceipt_id\x18\x01 \x01(\x0c\x12\x12\n\npolicy_uri\x18\x07 \x01(\t\x12\x14\n\x0cpersonal_key\x18\x08 \x01(\x0c\x12\x11\n\ttimestamp\x18\n \x01(\t\x12\x14\n\x0csession_data\x18\x0b \x01(\t\x12\x12\n\nerror_code\x18\x0c \x01(\t\x12\x30\n\x06issuer\x18\r \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\x0e \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12\x1c\n\x14\x66\x61ilure_reasons_json\x18\x0f \x01(\x0c\"i\n\x0e\x46\x61ilureReasons\x12W\n\x1crequirements_not_met_details\x18\x01 \x03(\x0b\x32\x31.yoti.core.compubapi_v1.RequirementsNotMetDetailsBh\n\x17\x63om.yoti.sharepubapi_v1B\x0cReceiptProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ReceiptPush_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\014ReceiptProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _SUCCESSRECEIPT._serialized_start=135
  _SUCCESSRECEIPT._serialized_end=550
  _FAILURERECEIPT._serialized_start=553
  _FAILURERECEIPT._serialized_end=828
  _FAILUREREASONS._serialized_start=830
  _FAILUREREASONS._serialized_end=935
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan.session.retrieve.document_fields_response import (
    DocumentFieldsResponse,
)
from yoti_python_sdk.doc_scan.session.retrieve.file_response import (
    FileResponse,
)
from yoti_python_sdk.doc_scan.session.retrieve.page_response import PageResponse
from yoti_python_sdk.doc_scan.session.retrieve.resource_response import ResourceResponse
from yoti_python_sdk.doc_scan.session.retrieve.task_response import (
    SupplementaryDocumentTextExtractionTaskResponse,
)


class SupplementaryDocumentResourceResponse(ResourceResponse):
    """
    Represents an Supplementary Document resource for a given session
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        ResourceResponse.__init__(self, data)

        self.__document_type = data.get("document_type", None)
        self.__issuing_country = data.get("issuing_country", None)
        self.__pages = [PageResponse(page) for page in data.get("pages", [])]
        self.__document_fields = (
            DocumentFieldsResponse(data["document_fields"])
            if "document_fields" in data.keys()
            else None
        )
        self.__document_file = (
            FileResponse(data["file"]) if "file" in data.keys() else None
        )

    @property
    def document_type(self):
        """
        Returns the supplementary document type, e.g. "UTILITY_BILL"

        :return: the document type
        :rtype: str or None
        """
        return self.__document_type

    @property
    def issuing_country(self):
        """
        Returns the issuing country of the supplementary document

        :return: the issuing country
        :rtype: str or None
        """
        return self.__issuing_country

    @property
    def pages(self):
        """
        Returns the individual pages of the supplementary document

        :return: the pages
        :rtype: list[PageResponse]
        """
        return self.__pages

    @property
    def document_fields(self):
        """
        Returns the associated document fields

        :return: the document fields
        :rtype: DocumentFieldsResponse
        """
        return self.__document_fields

    @property
    def document_file(self):
        """
        Returns the associated document file

        :return: the document file
        :rtype: FileResponse
        """
        return self.__document_file

    @property
    def text_extraction_tasks(self):
        """
        Returns a list of text extraction tasks associated
        with the supplementary document

        :return: list of text extraction tasks
        :rtype: list[TextExtractionTaskResponse]
        """
        return [
            task
            for task in self.tasks
            if isinstance(task, SupplementaryDocumentTextExtractionTaskResponse)
        ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class GeneratedMedia(object):
    """
    Represents media that has been generated by the session
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__id = data.get("id", None)
        self.__type = data.get("type", None)

    @property
    def id(self):
        """
        The ID of the generated media

        :return: the ID
        :rtype: str or None
        """
        return self.__id

    @property
    def type(self):
        """
        The type of the generated media, e.g. "JSON"

        :return: the type
        :rtype: str or None
        """
        return self.__type



from .breakdown_response import BreakdownResponse
from .recommendation_response import RecommendationResponse


class ReportResponse(object):
    """
    Represents a report for a given check
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__recommendation = (
            RecommendationResponse(data["recommendation"])
            if "recommendation" in data.keys()
            else None
        )

        self.__breakdown = [
            BreakdownResponse(breakdown) for breakdown in data.get("breakdown", [])
        ]

    @property
    def recommendation(self):
        """
        The recommendation given for a given check/task

        :return: the recommendation
        :rtype: RecommendationResponse
        """
        return self.__recommendation

    @property
    def breakdown(self):
        """
        A list of breakdowns for different sub-checks performed

        :return: the list of breakdowns
        :rtype: list[BreakdownResponse]
        """
        return self.__breakdown



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class ExtensionBuilder(object):
    def __init__(self):
        self.__extension = {}

    def with_extension_type(self, extension_type):
        """
        @param extension_type String label for the extension type
        """
        self.__extension["type"] = extension_type
        return self

    def with_content(self, content):
        """
        @param content The extension content
        """
        self.__extension["content"] = content
        return self

    def build(self):
        """
        @return Dictionary representation of an extension
        """
        return self.__extension.copy()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/Refresh.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from devicepubapi_v1 import StaticCredentialAuth_pb2 as devicepubapi__v1_dot_StaticCredentialAuth__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ttrpubapi_v1/Refresh.proto\x12\x17yoti.core.attrpubapi_v1\x1a*devicepubapi_v1/StaticCredentialAuth.proto\x1a\x1b\x63ompubapi_v1/Metadata.proto\"\xa7\x02\n\x0eRefreshRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12\x13\n\x0bwrapped_key\x18\x02 \x01(\x0c\x12\x16\n\x0e\x61uth_data_list\x18\x03 \x01(\x0c\x12\x15\n\rattribute_ids\x18\x04 \x03(\x0c\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12\x16\n\rfeature_flags\x18\xc1\x0c \x01(\x06\x12\x17\n\x0e\x63orrelation_id\x18\xc2\x0c \x01(\t\x12P\n\x16static_credential_auth\x18\xb8\x17 \x01(\x0b\x32/.yoti.core.devicepubapi_v1.StaticCredentialAuth\"\xa3\x01\n\x0fRefreshResponse\x12\x41\n\x08statuses\x18\x01 \x03(\x0e\x32/.yoti.core.attrpubapi_v1.RefreshResponse.Status\"M\n\x06Status\x12\r\n\tNO_CHANGE\x10\x00\x12\x0b\n\x07REVOKED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\r\n\tNOT_FOUND\x10\x03\x12\x0b\n\x07\x45XPIRED\x10\x04\x42o\n\x16\x63om.yoti.attrpubapi_v1B\x16RefreshAttributesProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Refresh_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\026RefreshAttributesProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _REFRESHREQUEST._serialized_start=130
  _REFRESHREQUEST._serialized_end=425
  _REFRESHRESPONSE._serialized_start=428
  _REFRESHRESPONSE._serialized_end=591
  _REFRESHRESPONSE_STATUS._serialized_start=514
  _REFRESHRESPONSE_STATUS._serialized_end=591
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/IdentityProfile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Address_pb2 as compubapi__v1_dot_Address__pb2
from . import DocumentTypes_pb2 as compubapi__v1_dot_DocumentTypes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"compubapi_v1/IdentityProfile.proto\x12\x16yoti.core.compubapi_v1\x1a\x1a\x63ompubapi_v1/Address.proto\x1a compubapi_v1/DocumentTypes.proto\"\x88\x02\n\x06Scheme\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.yoti.core.compubapi_v1.Scheme.Type\x12\x11\n\tobjective\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x34\n\x06\x63onfig\x18\x04 \x01(\x0b\x32$.yoti.core.compubapi_v1.SchemeConfig\"s\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x07\n\x03\x44\x42S\x10\x01\x12\x07\n\x03RTW\x10\x02\x12\x07\n\x03RTR\x10\x03\x12\x0b\n\x07\x44\x42S_RTW\x10\x04\x12\x0c\n\x08IDENTITY\x10\x05\x12\x19\n\x15IDENTITY_PLUS_ADDRESS\x10\x06\x12\x0b\n\x07\x43\x41N_CRC\x10\x07\"[\n\x0cSchemeConfig\x12K\n\x0f\x64ocument_filter\x18\x01 \x01(\x0b\x32\x32.yoti.core.compubapi_v1.DocumentRestrictionsFilter\"\x8e\x01\n\x1bIdentityProfileRequirements\x12?\n\x0ftrust_framework\x18\x01 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\x12.\n\x06scheme\x18\x02 \x01(\x0b\x32\x1e.yoti.core.compubapi_v1.Scheme\"`\n#AdvancedIdentityProfileRequirements\x12\x39\n\x08profiles\x18\x01 \x03(\x0b\x32\'.yoti.core.compubapi_v1.AdvancedProfile\"\x83\x01\n\x0f\x41\x64vancedProfile\x12?\n\x0ftrust_framework\x18\x01 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\x12/\n\x07schemes\x18\x02 \x03(\x0b\x32\x1e.yoti.core.compubapi_v1.Scheme\"\x1d\n\x07Subject\x12\x12\n\nsubject_id\x18\x01 \x01(\t\"\xc8\x01\n\x0fIdentityDetails\x12\x13\n\x0bgiven_names\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x13\n\x0bmiddle_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x11\n\tfull_name\x18\x05 \x01(\t\x12\x15\n\rdate_of_birth\x18\x06 \x01(\t\x12\x38\n\x0f\x63urrent_address\x18\x07 \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Address\"u\n\x1eVerificationReportRequirements\x12S\n\x1dgeneral_evidence_requirements\x18\x01 \x01(\x0e\x32,.yoti.core.compubapi_v1.EvidenceRequirements*A\n\x0eTrustFramework\x12\x10\n\x0cUNDEFINED_TF\x10\x00\x12\x0c\n\x08UK_TFIDA\x10\x01\x12\x0f\n\x0bYOTI_GLOBAL\x10\x02*z\n\x14\x45videnceRequirements\x12\x10\n\x0cUNDEFINED_ER\x10\x00\x12\x11\n\rOMIT_EVIDENCE\x10\x01\x12\x18\n\x14METADATA_AND_DETAILS\x10\x02\x12#\n\x1fMETADATA_AND_DETAILS_AND_IMAGES\x10\x03\x42j\n\x15\x63om.yoti.compubapi_v1B\x14IdentityProfileProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IdentityProfile_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\024IdentityProfileProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _TRUSTFRAMEWORK._serialized_start=1214
  _TRUSTFRAMEWORK._serialized_end=1279
  _EVIDENCEREQUIREMENTS._serialized_start=1281
  _EVIDENCEREQUIREMENTS._serialized_end=1403
  _SCHEME._serialized_start=125
  _SCHEME._serialized_end=389
  _SCHEME_TYPE._serialized_start=274
  _SCHEME_TYPE._serialized_end=389
  _SCHEMECONFIG._serialized_start=391
  _SCHEMECONFIG._serialized_end=482
  _IDENTITYPROFILEREQUIREMENTS._serialized_start=485
  _IDENTITYPROFILEREQUIREMENTS._serialized_end=627
  _ADVANCEDIDENTITYPROFILEREQUIREMENTS._serialized_start=629
  _ADVANCEDIDENTITYPROFILEREQUIREMENTS._serialized_end=725
  _ADVANCEDPROFILE._serialized_start=728
  _ADVANCEDPROFILE._serialized_end=859
  _SUBJECT._serialized_start=861
  _SUBJECT._serialized_end=890
  _IDENTITYDETAILS._serialized_start=893
  _IDENTITYDETAILS._serialized_end=1093
  _VERIFICATIONREPORTREQUIREMENTS._serialized_start=1095
  _VERIFICATIONREPORTREQUIREMENTS._serialized_end=1212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from cryptography.fernet import base64

from yoti_python_sdk.protobuf.protobuf import Protobuf

CONTENT_TYPE_JPEG = "jpeg"
CONTENT_TYPE_PNG = "png"


class Image:
    def __init__(self, image_bytes, image_content_type):
        if image_content_type == Protobuf.CT_JPEG:
            self.__content_type = CONTENT_TYPE_JPEG
        elif image_content_type == Protobuf.CT_PNG:
            self.__content_type = CONTENT_TYPE_PNG
        else:
            raise TypeError(
                "Content type '{0}' is not a supported image type".format(
                    image_content_type
                )
            )

        self.__data = image_bytes

    @staticmethod
    def allowed_types():
        return [Protobuf.CT_PNG, Protobuf.CT_JPEG]

    @property
    def data(self):
        return self.__data

    @property
    def content_type(self):
        return self.__content_type

    def mime_type(self):
        return "image/{0}".format(self.__content_type)

    def base64_content(self):
        data = base64.b64encode(self.__data).decode("utf-8")
        return "data:{0};base64,{1}".format(self.mime_type(), data)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan.constants import PROOF_OF_ADDRESS
from .objective import Objective


class ProofOfAddressObjective(Objective):
    """
    Proof of address document objective
    """

    @property
    def type(self):
        return PROOF_OF_ADDRESS


class ProofOfAddressObjectiveBuilder(object):
    """
    Builder to assist creation of :class:`ProofOfAddressObjective`
    """

    def build(self):
        """
        :return: the proof of address objective
        :rtype: ProofOfAddressObjective
        """
        return ProofOfAddressObjective()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/Address.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63ompubapi_v1/Address.proto\x12\x16yoti.core.compubapi_v1\"\xf4\x03\n\x07\x41\x64\x64ress\x12\x16\n\x0e\x61\x64\x64ress_format\x18\x01 \x01(\r\x12\x0f\n\x07\x63\x61re_of\x18\x02 \x01(\t\x12\x14\n\x0csub_building\x18\x03 \x01(\t\x12\x17\n\x0f\x62uilding_number\x18\x04 \x01(\t\x12\x10\n\x08\x62uilding\x18\x05 \x01(\t\x12\x0e\n\x06street\x18\x06 \x01(\t\x12\x10\n\x08landmark\x18\x07 \x01(\t\x12\x15\n\raddress_line1\x18\x08 \x01(\t\x12\x15\n\raddress_line2\x18\t \x01(\t\x12\x15\n\raddress_line3\x18\n \x01(\t\x12\x15\n\raddress_line4\x18\x0b \x01(\t\x12\x15\n\raddress_line5\x18\x0c \x01(\t\x12\x15\n\raddress_line6\x18\r \x01(\t\x12\x10\n\x08locality\x18\x0e \x01(\t\x12\x11\n\ttown_city\x18\x0f \x01(\t\x12\x13\n\x0bsubdistrict\x18\x10 \x01(\t\x12\x10\n\x08\x64istrict\x18\x11 \x01(\t\x12\r\n\x05state\x18\x12 \x01(\t\x12\x13\n\x0bpostal_code\x18\x13 \x01(\t\x12\x13\n\x0bpost_office\x18\x14 \x01(\t\x12\x13\n\x0b\x63ountry_iso\x18\x15 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x16 \x01(\t\x12\x19\n\x11\x66ormatted_address\x18\x17 \x01(\t\x12\r\n\x05udprn\x18\x18 \x01(\tBb\n\x15\x63om.yoti.compubapi_v1B\x0c\x41\x64\x64ressProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Address_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\014AddressProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _ADDRESS._serialized_start=55
  _ADDRESS._serialized_end=555
# @@protoc_insertion_point(module_scope)



from .document_authenticity import RequestedDocumentAuthenticityCheckBuilder
from .document_comparison import RequestedIDDocumentComparisonCheckBuilder
from .face_match import RequestedFaceMatchCheckBuilder
from .liveness import RequestedLivenessCheckBuilder
from .watchlist_screen import WatchlistScreeningCheckBuilder


__all__ = [
    "RequestedDocumentAuthenticityCheckBuilder",
    "RequestedIDDocumentComparisonCheckBuilder",
    "RequestedFaceMatchCheckBuilder",
    "RequestedLivenessCheckBuilder",
    "WatchlistScreeningCheckBuilder",
]



import time
import uuid
from abc import ABCMeta
from abc import abstractmethod
from json import JSONEncoder


class YotiSerializable(object):
    """
    Used to describe a class that is serializable by :class:`YotiEncoder`.
    """

    __metaclass__ = ABCMeta

    @abstractmethod
    def to_json(self):
        raise NotImplementedError


class YotiEncoder(JSONEncoder):
    def default(self, o):
        if isinstance(o, YotiSerializable):
            return o.to_json()
        return JSONEncoder.default(self, o)


def create_nonce():
    """
    Create and return a nonce
    \
    :return: the nonce
    """
    return uuid.uuid4()


def create_timestamp():
    """
    Create and return a timestamp

    :return: the timestamp as a int
    """
    return int(time.time() * 1000)


def remove_null_values(d):
    """
    Delete keys with the value ``None`` in a dictionary, recursively. (None serializes to null)
    """
    for key, value in list(d.items()):
        if value is None:
            del d[key]
        elif isinstance(value, dict):
            remove_null_values(value)
    return d



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/Location.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsharepubapi_v1/Location.proto\x12\x18yoti.core.sharepubapi_v1\"K\n\x08Location\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12\x1a\n\x12uncertainty_radius\x18\x03 \x01(\x01\x42i\n\x17\x63om.yoti.sharepubapi_v1B\rLocationProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Location_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\rLocationProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _LOCATION._serialized_start=59
  _LOCATION._serialized_end=134
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-

from .wanted_attribute_builder import WantedAttributeBuilder
from .wanted_anchor_builder import WantedAnchorBuilder
from .source_constraint_builder import SourceConstraintBuilder
from .dynamic_policy_builder import DynamicPolicyBuilder

__all__ = [
    "DynamicPolicyBuilder",
    "WantedAttributeBuilder",
    "WantedAnchorBuilder",
    "SourceConstraintBuilder",
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

ID_DOCUMENT_AUTHENTICITY = "ID_DOCUMENT_AUTHENTICITY"
ID_DOCUMENT_COMPARISON = "ID_DOCUMENT_COMPARISON"
ID_DOCUMENT_TEXT_DATA_CHECK = "ID_DOCUMENT_TEXT_DATA_CHECK"
ID_DOCUMENT_TEXT_DATA_EXTRACTION = "ID_DOCUMENT_TEXT_DATA_EXTRACTION"
ID_DOCUMENT_FACE_MATCH = "ID_DOCUMENT_FACE_MATCH"
LIVENESS = "LIVENESS"
ZOOM = "ZOOM"
SUPPLEMENTARY_DOCUMENT_TEXT_DATA_CHECK = "SUPPLEMENTARY_DOCUMENT_TEXT_DATA_CHECK"
SUPPLEMENTARY_DOCUMENT_TEXT_DATA_EXTRACTION = (
    "SUPPLEMENTARY_DOCUMENT_TEXT_DATA_EXTRACTION"
)

CAMERA = "CAMERA"
CAMERA_AND_UPLOAD = "CAMERA_AND_UPLOAD"

RESOURCE_UPDATE = "RESOURCE_UPDATE"
TASK_COMPLETION = "TASK_COMPLETION"
CHECK_COMPLETION = "CHECK_COMPLETION"
SESSION_COMPLETION = "SESSION_COMPLETION"

ID_DOCUMENT = "ID_DOCUMENT"
SUPPLEMENTARY_DOCUMENT = "SUPPLEMENTARY_DOCUMENT"
ORTHOGONAL_RESTRICTIONS = "ORTHOGONAL_RESTRICTIONS"
DOCUMENT_RESTRICTIONS = "DOCUMENT_RESTRICTIONS"
INCLUSION_WHITELIST = "WHITELIST"
INCLUSION_BLACKLIST = "BLACKLIST"

ALWAYS = "ALWAYS"
FALLBACK = "FALLBACK"
NEVER = "NEVER"

DESIRED = "DESIRED"
IGNORE = "IGNORE"

PROOF_OF_ADDRESS = "PROOF_OF_ADDRESS"

WATCHLIST_SCREENING_CHECK_TYPE = "WATCHLIST_SCREENING"



from yoti_python_sdk.doc_scan import constants
from .task_response import (
    TaskResponse,
    TextExtractionTaskResponse,
    SupplementaryDocumentTextExtractionTaskResponse,
)


class ResourceResponse(object):
    """
    Represents a resource
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__id = data.get("id", None)
        self.__tasks = [self.__parse_task(task) for task in data.get("tasks", [])]

    @staticmethod
    def __parse_task(task):
        """
        Return a parsed task from a dictionary

        :param task: the raw task
        :type task: dict
        :return: the parsed task
        :rtype: TaskResponse
        """
        types = {
            constants.ID_DOCUMENT_TEXT_DATA_EXTRACTION: TextExtractionTaskResponse,
            constants.SUPPLEMENTARY_DOCUMENT_TEXT_DATA_EXTRACTION: SupplementaryDocumentTextExtractionTaskResponse,
        }
        clazz = types.get(
            task.get("type", None), TaskResponse  # Default fallback for task type
        )
        return clazz(task)

    @property
    def id(self):
        """
        The ID of the resource

        :return: the id
        :rtype: str
        """
        return self.__id

    @property
    def tasks(self):
        """
        Tasks associated with a resource

        :return: the list of tasks
        :rtype: list[TaskResponse]
        """
        return self.__tasks



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/DeleteSuperseded.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$attrpubapi_v1/DeleteSuperseded.proto\x12\x17yoti.core.attrpubapi_v1\x1a\x1b\x63ompubapi_v1/Metadata.proto\"\x9d\x02\n\x17\x44\x65leteSupersededRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12\x13\n\x0bwrapped_key\x18\x02 \x01(\x0c\x12\x16\n\x0e\x61uth_data_list\x18\x03 \x01(\x0c\x12\x15\n\rattribute_ids\x18\x04 \x03(\x0c\x12\x1c\n\x14\x61ttributes_backup_id\x18\x05 \x01(\x0c\x12\x1f\n\x17\x65ncrypted_attribute_ids\x18\x06 \x03(\x0c\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12\x16\n\rfeature_flags\x18\xc1\x0c \x01(\x06\x12\x17\n\x0e\x63orrelation_id\x18\xc2\x0c \x01(\tBn\n\x16\x63om.yoti.attrpubapi_v1B\x15\x44\x65leteSupersededProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DeleteSuperseded_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\025DeleteSupersededProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _DELETESUPERSEDEDREQUEST._serialized_start=95
  _DELETESUPERSEDEDREQUEST._serialized_end=380
# @@protoc_insertion_point(module_scope)



from yoti_python_sdk.doc_scan.constants import INCLUSION_BLACKLIST
from yoti_python_sdk.doc_scan.constants import INCLUSION_WHITELIST
from yoti_python_sdk.doc_scan.constants import ORTHOGONAL_RESTRICTIONS
from yoti_python_sdk.utils import YotiSerializable, remove_null_values
from .document_filter import DocumentFilter


class CountryRestriction(YotiSerializable):
    def __init__(self, inclusion, country_codes):
        self.__inclusion = inclusion
        self.__country_codes = country_codes

    @property
    def inclusion(self):
        """
        Returns the inclusion for the country restriction

        :return: the inclusion
        :rtype: str
        """
        return self.__inclusion

    @property
    def country_codes(self):
        """
        Returns the country codes for the restriction

        :return: the country codes
        :rtype: list[str]
        """
        return self.__country_codes

    def to_json(self):
        return remove_null_values(
            {"inclusion": self.inclusion, "country_codes": self.country_codes}
        )


class TypeRestriction(YotiSerializable):
    def __init__(self, inclusion, document_types):
        self.__inclusion = inclusion
        self.__document_types = document_types

    @property
    def inclusion(self):
        """
        Returns the inclusion for the type restriction

        :return: the inclusion
        :rtype: str
        """
        return self.__inclusion

    @property
    def document_types(self):
        """
        Returns the document types for the restriction

        :return: the document types
        :rtype: list[str]
        """
        return self.__document_types

    def to_json(self):
        return remove_null_values(
            {"inclusion": self.inclusion, "document_types": self.document_types}
        )


class OrthogonalRestrictionsFilter(DocumentFilter):
    def __init__(self, country_restriction, type_restriction, allow_non_latin_documents=None):
        DocumentFilter.__init__(self, filter_type=ORTHOGONAL_RESTRICTIONS)

        self.__country_restriction = country_restriction
        self.__type_restriction = type_restriction
        self.__allow_non_latin_documents = allow_non_latin_documents

    @property
    def country_restriction(self):
        """
        Returns the country restriction for the orthogonal filter

        :return: the country restriction
        :rtype: CountryRestriction
        """
        return self.__country_restriction

    @property
    def type_restriction(self):
        """
        Returns the document type restriction for the orthogonal filter

        :return: the document type restriction
        :rtype: TypeRestriction
        """
        return self.__type_restriction

    @property
    def allow_non_latin_documents(self):
        """
        Returns the flag for whether non-latin documents are allowed.

        :return: allow_non_latin_documents
        :rtype: bool
        """
        return self.__allow_non_latin_documents

    def to_json(self):
        parent = DocumentFilter.to_json(self)
        parent["country_restriction"] = self.country_restriction
        parent["type_restriction"] = self.type_restriction
        if self.__allow_non_latin_documents is not None:
            parent["allow_non_latin_documents"] = self.__allow_non_latin_documents

        return remove_null_values(parent)


class OrthogonalRestrictionsFilterBuilder(object):
    """
    Builder used to create an orthogonal restriction filter.

    Example::

        filter = (OrthogonalRestrictionsFilterBuilder()
                  .with_whitelisted_country_codes(["GBR", "USA"])
                  .with_whitelisted_document_types(["PASSPORT"])
                  .build())

    """

    def __init__(self):
        self.__country_restriction = None
        self.__type_restriction = None
        self.__allow_non_latin_documents = None

    def with_whitelisted_country_codes(self, country_codes):
        """
        Sets a whitelisted list of country codes on the filter

        :param country_codes: List of country codes
        :type country_codes: list[str]
        :return: the builder
        :rtype: OrthogonalRestrictionsFilterBuilder
        """
        self.__country_restriction = CountryRestriction(
            INCLUSION_WHITELIST, country_codes
        )
        return self

    def with_blacklisted_country_codes(self, country_codes):
        """
        Sets a blacklisted list of country codes on the filter

        :param country_codes: list of country codes
        :type country_codes: list[str]
        :return: the builder
        :rtype: OrthogonalRestrictionsFilterBuilder
        """
        self.__country_restriction = CountryRestriction(
            INCLUSION_BLACKLIST, country_codes
        )
        return self

    def with_whitelisted_document_types(self, document_types):
        """
        Sets a whitelisted list of document types on the filter

        :param document_types: list of document types
        :type document_types: list[str]
        :return: the builder
        :rtype: OrthogonalRestrictionsFilterBuilder
        """
        self.__type_restriction = TypeRestriction(INCLUSION_WHITELIST, document_types)
        return self

    def with_blacklisted_document_types(self, document_types):
        """
        Sets a blacklisted list of document types on the filter

        :param document_types: list of document types
        :type document_types: list[str]
        :return: the builder
        :rtype: OrthogonalRestrictionsFilterBuilder
        """
        self.__type_restriction = TypeRestriction(INCLUSION_BLACKLIST, document_types)
        return self

    def allow_non_latin_documents(self):
        """
        Sets a True value for "allow non-latin documents" flag.

        :return: the builder
        :rtype: OrthogonalRestrictionsFilterBuilder
        """
        self.__allow_non_latin_documents = True
        return self

    def disable_non_latin_documents(self):
        """
        Sets a False value for "allow non-latin documents" flag.

        :return: the builder
        :rtype: OrthogonalRestrictionsFilterBuilder
        """
        self.__allow_non_latin_documents = False
        return self

    def build(self):
        """
        Builds the orthogonal filter, using the supplied whitelisted/blacklisted values

        :return: the built filter
        :rtype: OrthogonalRestrictionsFilter
        """
        return OrthogonalRestrictionsFilter(
            self.__country_restriction, self.__type_restriction, self.__allow_non_latin_documents
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/AttributeDisplayResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,attrpubapi_v1/AttributeDisplayResponse.proto\x12\x17yoti.core.attrpubapi_v1\"(\n\x18\x41ttributeDisplayResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42v\n\x16\x63om.yoti.attrpubapi_v1B\x1d\x41ttributeDisplayResponseProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AttributeDisplayResponse_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\035AttributeDisplayResponseProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _ATTRIBUTEDISPLAYRESPONSE._serialized_start=73
  _ATTRIBUTEDISPLAYRESPONSE._serialized_end=113
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import base64


class MediaValue(object):
    def __init__(self, content_type, content):
        self.__mime_type = content_type
        self.__content = content

    @property
    def mime_type(self):
        return self.__mime_type

    @property
    def content(self):
        return self.__content

    @property
    def base64_content(self):
        return "data:%s;base64,%s" % (
            self.mime_type,
            base64.b64encode(self.__content).decode("utf-8"),
        )



from .extension_builder import ExtensionBuilder
from .location_constraint_extension_builder import LocationConstraintExtensionBuilder
from .transactional_flow_extension_builder import TransactionalFlowExtensionBuilder
from .third_party_attribute_extension import ThirdPartyAttributeExtension

__all__ = [
    "ExtensionBuilder",
    "LocationConstraintExtensionBuilder",
    "TransactionalFlowExtensionBuilder",
    "ThirdPartyAttributeExtension",
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.config import (
    ANCHOR_VALUE_PASSPORT,
    ANCHOR_VALUE_PASS_CARD,
    ANCHOR_VALUE_NATIONAL_ID,
    ANCHOR_VALUE_DRIVING_LICENCE,
)

from .wanted_anchor_builder import WantedAnchorBuilder


class SourceConstraintBuilder(object):
    def __init__(self):
        self.__soft_preference = False
        self.__anchors = []

    def with_soft_preference(self, value=True):
        """
        :param value: If true, this will be treated as a soft preference, otherwise
                      this will be treated as a hard requirement
        """
        self.__soft_preference = value
        return self

    def with_anchor(self, anchor):
        """
        :param anchor: Add an anchor to the source constraint.
        It is recommended to use the other helper methods instead of this one
        """
        self.__anchors.append(anchor)
        return self

    def with_anchor_by_name(self, value, subtype=""):
        """
        :param value: The type of anchor wanted, represented by a string
        :param subtype: The subtype information for the anchor as a string
        """
        anchor = WantedAnchorBuilder().with_value(value).with_subtype(subtype).build()
        return self.with_anchor(anchor)

    def with_passport(self, subtype=""):
        """
        :param subtype: Subtype information as a string
        """
        return self.with_anchor_by_name(ANCHOR_VALUE_PASSPORT, subtype)

    def with_national_id(self, subtype=""):
        """
        :param subtype: Subtype information as a string
        """
        return self.with_anchor_by_name(ANCHOR_VALUE_NATIONAL_ID, subtype)

    def with_passcard(self, subtype=""):
        """
        :param subtype: Subtype information as a string
        """
        return self.with_anchor_by_name(ANCHOR_VALUE_PASS_CARD, subtype)

    def with_driving_licence(self, subtype=""):
        """
        :param subtype: Subtype information as a string
        """
        return self.with_anchor_by_name(ANCHOR_VALUE_DRIVING_LICENCE, subtype)

    def build(self):
        """
        :returns: A dict describing the source constraint
        """
        return {
            "type": "SOURCE",
            "preferred_sources": {
                "soft_preference": self.__soft_preference,
                "anchors": self.__anchors,
            },
        }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/DataPrivacy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ompubapi_v1/DataPrivacy.proto\x12\x16yoti.core.compubapi_v1*q\n\x0b\x44\x61taPrivacy\x12\x1a\n\x16\x44\x41TA_PRIVACY_UNDEFINED\x10\x00\x12$\n DATA_PRIVACY_CONTROLLERS_ALLOWED\x10\x01\x12 \n\x1c\x44\x41TA_PRIVACY_PROCESSORS_ONLY\x10\x02\x42\x66\n\x15\x63om.yoti.compubapi_v1B\x10\x44\x61taPrivacyProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DataPrivacy_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\020DataPrivacyProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _DATAPRIVACY._serialized_start=58
  _DATAPRIVACY._serialized_end=171
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan.constants import CAMERA
from yoti_python_sdk.doc_scan.constants import CAMERA_AND_UPLOAD
from yoti_python_sdk.utils import YotiSerializable, remove_null_values


class SdkConfig(YotiSerializable):
    """
    Provides configuration properties for the web/native clients
    """

    def __init__(
        self,
        allowed_capture_methods,
        primary_colour,
        secondary_colour,
        font_colour,
        locale,
        preset_issuing_country,
        success_url,
        error_url,
        allow_handoff=None,
        privacy_policy_url=None,
    ):
        """
        :param allowed_capture_methods: the allowed capture methods
        :type allowed_capture_methods: str
        :param primary_colour: the primary colour
        :type primary_colour: str
        :param secondary_colour: the secondary colour
        :type secondary_colour: str
        :param font_colour: the font colour
        :type font_colour: str
        :param locale: the locale
        :type locale: str
        :param preset_issuing_country: the preset issuing country
        :type preset_issuing_country: str
        :param success_url: the success url
        :type success_url: str
        :param error_url: the error url
        :type error_url: str
        :param privacy_policy_url: the privacy policy url
        :type privacy_policy_url: str
        :param allow_handoff: boolean flag for allow_handoff
        :type allow_handoff: bool
        """
        self.__allowed_capture_methods = allowed_capture_methods
        self.__primary_colour = primary_colour
        self.__secondary_colour = secondary_colour
        self.__font_colour = font_colour
        self.__locale = locale
        self.__preset_issuing_country = preset_issuing_country
        self.__success_url = success_url
        self.__error_url = error_url
        self.__privacy_policy_url = privacy_policy_url
        self.__allow_handoff = allow_handoff

    @property
    def allowed_capture_methods(self):
        """
        The methods allowed for capturing document images

        :return: the allowed capture methods
        """
        return self.__allowed_capture_methods

    @property
    def primary_colour(self):
        """
        The primary colour

        :return: the primary colour
        """
        return self.__primary_colour

    @property
    def secondary_colour(self):
        """
        The secondary colour

        :return: the secondary colour
        """
        return self.__secondary_colour

    @property
    def font_colour(self):
        """
        The font colour

        :return: the font colour
        """
        return self.__font_colour

    @property
    def locale(self):
        """
        The locale

        :return: the locale
        """
        return self.__locale

    @property
    def preset_issuing_country(self):
        """
        The preset issuing country

        :return: the preset issuing country
        """
        return self.__preset_issuing_country

    @property
    def success_url(self):
        """
        The success URL

        :return: the success url
        """
        return self.__success_url

    @property
    def error_url(self):
        """
        The error URL

        :return: the error url
        """
        return self.__error_url

    @property
    def privacy_policy_url(self):
        """
        The privacy policy URL

        :return: the privacy policy url
        """
        return self.__privacy_policy_url

    @property
    def allow_handoff(self):
        """
        Flag to enable/disable relying business to handoff
        support when creating a session.

        :return: the allow_handoff
        """
        return self.__allow_handoff

    def to_json(self):
        return remove_null_values(
            {
                "allowed_capture_methods": self.allowed_capture_methods,
                "primary_colour": self.primary_colour,
                "secondary_colour": self.secondary_colour,
                "font_colour": self.font_colour,
                "locale": self.locale,
                "preset_issuing_country": self.preset_issuing_country,
                "success_url": self.success_url,
                "error_url": self.error_url,
                "privacy_policy_url": self.privacy_policy_url,
                "allow_handoff": self.allow_handoff,
            }
        )


class SdkConfigBuilder(object):
    """
    Builder to assist in the creation of :class:`SdkConfig`
    """

    def __init__(self):
        self.__allowed_capture_methods = None
        self.__primary_colour = None
        self.__secondary_colour = None
        self.__font_colour = None
        self.__locale = None
        self.__preset_issuing_country = None
        self.__success_url = None
        self.__error_url = None
        self.__privacy_policy_url = None
        self.__allow_handoff = None

    def with_allowed_capture_methods(self, allowed_capture_methods):
        """
        Sets the allowed capture methods on the builder

        :param allowed_capture_methods: the allowed capture methods
        :type allowed_capture_methods: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__allowed_capture_methods = allowed_capture_methods
        return self

    def with_allows_camera(self):
        """
        Sets the allowed capture method to "CAMERA"

        :return: the builder
        :rtype: SdkConfigBuilder
        """
        return self.with_allowed_capture_methods(CAMERA)

    def with_allows_camera_and_upload(self):
        """
        Sets the allowed capture method to "CAMERA_AND_UPLOAD"

        :return: the builder
        :rtype: SdkConfigBuilder
        """
        return self.with_allowed_capture_methods(CAMERA_AND_UPLOAD)

    def with_primary_colour(self, colour):
        """
        Sets the primary colour to be used by the web/native client

        :param colour: the primary colour, hexadecimal value e.g. #ff0000
        :type colour: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__primary_colour = colour
        return self

    def with_secondary_colour(self, colour):
        """
        Sets the secondary colour to be used by the web/native client (used on the button)

        :param colour: the secondary colour, hexadecimal value e.g. #ff0000
        :type colour: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__secondary_colour = colour
        return self

    def with_font_colour(self, colour):
        """
        Sets the font colour to be used by the web/native client (used on the button)

        :param colour: the font colour, hexadecimal value e.g. #ff0000
        :type colour: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__font_colour = colour
        return self

    def with_locale(self, locale):
        """
        Sets the language locale use by the web/native client

        :param locale: the locale, e.g. "en"
        :type locale: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__locale = locale
        return self

    def with_preset_issuing_country(self, country):
        """
        Sets the preset issuing country used by the web/native client

        :param country: the preset issuing country
        :type country: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__preset_issuing_country = country
        return self

    def with_success_url(self, url):
        """
        Sets the success URL for the redirect that follows the web/native client uploading documents successfully

        :param url: the success URL
        :type url: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__success_url = url
        return self

    def with_error_url(self, url):
        """
        Sets the error URL for the redirect that follows the web/native client uploading documents unsuccessfully

        :param url: the error URL
        :type url: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__error_url = url
        return self

    def with_privacy_policy_url(self, url):
        """
        Sets the privacy policy URL

        :param url: the privacy policy URL
        :type url: str
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__privacy_policy_url = url
        return self

    def with_allow_handoff(self, flag):
        """
        Sets the allow handoff flag

        :param flag: boolean value for flag
        :type flag: bool
        :return: the builder
        :rtype: SdkConfigBuilder
        """
        self.__allow_handoff = flag
        return self

    def build(self):
        return SdkConfig(
            self.__allowed_capture_methods,
            self.__primary_colour,
            self.__secondary_colour,
            self.__font_colour,
            self.__locale,
            self.__preset_issuing_country,
            self.__success_url,
            self.__error_url,
            self.__allow_handoff,
            self.__privacy_policy_url,
        )



from yoti_python_sdk.crypto import Crypto
from yoti_python_sdk.utils import create_nonce, create_timestamp
from yoti_python_sdk.config import (
    X_YOTI_AUTH_DIGEST,
    X_YOTI_SDK,
    SDK_IDENTIFIER,
    X_YOTI_SDK_VERSION,
    JSON_CONTENT_TYPE,
)
from cryptography.fernet import base64
from abc import ABCMeta, abstractmethod

import yoti_python_sdk
import requests

try:  # pragma: no cover
    from urllib.parse import urlencode
except ImportError:  # pragma: no cover
    from urllib import urlencode

HTTP_POST = "POST"
HTTP_GET = "GET"
HTTP_SUPPORTED_METHODS = ["POST", "PUT", "PATCH", "GET", "DELETE"]


class YotiResponse(object):
    def __init__(self, status_code, text, headers=None, content=None):
        if headers is None:
            headers = {}

        self.status_code = status_code
        self.text = text
        self.content = content
        self.headers = headers


class RequestHandler(object):
    """
    Default request handler for signing requests using the requests library.
    This type can be inherited and the execute method overridden to use any
    preferred HTTP library.  Must return type YotiResponse for use in the SDK.
    """

    __metaclass__ = ABCMeta  # Python 2 compatability

    @staticmethod
    @abstractmethod
    def execute(request):
        return NotImplemented


class DefaultRequestHandler(RequestHandler):
    @staticmethod
    def execute(request):
        """
        Execute the HTTP request supplied
        """
        if not isinstance(request, SignedRequest):
            raise TypeError("RequestHandler expects instance of SignedRequest")

        response = requests.request(
            url=request.url,
            method=request.method,
            data=request.data,
            headers=request.headers,
        )

        return YotiResponse(
            status_code=response.status_code,
            text=response.text,
            headers=response.headers,
            content=response.content,
        )


class SignedRequest(object):
    def __init__(self, url, http_method, payload, headers, request_handler=None):
        self.__url = url
        self.__http_method = http_method
        self.__payload = payload
        self.__headers = headers
        self.__request_handler = request_handler

    @property
    def url(self):
        """
        Returns the URL for the SignedRequest
        """
        return self.__url

    @property
    def method(self):
        """
        Returns the HTTP method for the SignedRequest
        """
        return self.__http_method

    @property
    def data(self):
        """
        Returns the payload data for the SignedRequest
        """
        return self.__payload

    @property
    def headers(self):
        """
        Returns the HTTP headers for the SignedRequest
        """
        return self.__headers

    def execute(self):
        """
        Send the signed request, using the default RequestHandler if one has not be supplied
        """
        if self.__request_handler is None:
            return DefaultRequestHandler.execute(self)

        return self.__request_handler.execute(self)

    @staticmethod
    def builder():
        """
        Returns an instance of SignedRequestBuilder
        """
        return SignedRequestBuilder()


class SignedRequestBuilder(object):
    def __init__(self):
        self.__crypto = None
        self.__base_url = None
        self.__endpoint = None
        self.__http_method = None
        self.__params = None
        self.__headers = None
        self.__payload = None
        self.__request_handler = None

    def with_pem_file(self, pem_file):
        """
        Sets the PEM file to be used for signing the request.  Can be an instance of yoti_python_sdk.crypto.Crypto
        or a path to a PEM file
        """
        if isinstance(pem_file, Crypto):
            self.__crypto = pem_file
        else:
            self.__crypto = Crypto.read_pem_file(pem_file)

        return self

    def with_base_url(self, base_url):
        """
        Sets the base URL for the signed request
        """
        self.__base_url = base_url
        return self

    def with_endpoint(self, endpoint):
        """
        Sets the endpoint for the signed request
        """
        self.__endpoint = endpoint
        return self

    def with_payload(self, payload):
        """
        Sets the payload for the signed request.  Must be a valid JSON string
        """
        self.__payload = payload
        return self

    def with_param(self, name, value):
        """
        Sets a query param to be used with the endpoint
        """
        if self.__params is None:
            self.__params = {}

        self.__params[name] = value
        return self

    def with_header(self, name, value):
        """
        Sets a HTTP header to be used in the request
        """
        if self.__headers is None:
            self.__headers = {}

        self.__headers[name] = value
        return self

    def with_http_method(self, http_method):
        """
        Sets the HTTP method to be used in the request
        """
        if http_method not in HTTP_SUPPORTED_METHODS:
            raise ValueError("{} is an unsupported HTTP method".format(http_method))

        self.__http_method = http_method
        return self

    def with_request_handler(self, handler):
        # If no handler is passed, just return as the default will be used
        if handler is None:
            return self

        try:
            if not issubclass(handler, RequestHandler):
                raise TypeError(
                    "Handler must be instance of yoti_python_sdk.http.RequestHandler"
                )
        except Exception:
            # ABC
            raise TypeError(
                "Handler must be instance of yoti_python_sdk.http.RequestHandler"
            )

        self.__request_handler = handler
        return self

    def with_post(self):
        """
        Sets the HTTP method for a POST request
        """
        self.with_http_method(HTTP_POST)
        return self

    def with_get(self):
        """
        Sets the HTTP method for a GET request
        """
        self.with_http_method(HTTP_GET)
        return self

    def __append_query_params(self, query_params=None):
        """
        Appends supplied query params in a dict to default query params.
        Returns a url encoded query param string
        """
        required = {"nonce": create_nonce(), "timestamp": create_timestamp()}

        query_params = self.__merge_dictionary(query_params, required)
        return "?{}".format(urlencode(query_params))

    @staticmethod
    def __merge_dictionary(a, b):
        """
        Merges two dictionaries a and b, with b taking precedence over a
        """
        if a is None:
            return b

        merged = a.copy()
        merged.update(b)
        return merged

    def __get_request_headers(self, path, http_method, content):
        """
        Returns a dictionary of request headers, also using supplied headers from builder.  Default headers take precedence.
        """
        request = self.__create_request(http_method, path, content)
        sdk_version = yoti_python_sdk.__version__

        default = {
            X_YOTI_AUTH_DIGEST: self.__crypto.sign(request),
            X_YOTI_SDK: SDK_IDENTIFIER,
            X_YOTI_SDK_VERSION: "{0}-{1}".format(SDK_IDENTIFIER, sdk_version),
            "Content-Type": JSON_CONTENT_TYPE,
            "Accept": JSON_CONTENT_TYPE,
        }

        if self.__headers is not None:
            return self.__merge_dictionary(self.__headers, default)

        return default

    @staticmethod
    def __create_request(http_method, path, content):
        """
        Creates a concatenated string that is used in the X-YOTI-AUTH-DIGEST header
        :param http_method:
        :param path:
        :param content:
        :return:
        """

        request = "{}&{}".format(http_method, path)

        if content is not None:
            b64encoded = base64.b64encode(content)
            b64ascii = b64encoded.decode("ascii")
            request += "&" + b64ascii

        return request

    def __validate_request(self):
        """
        Validates the request object to ensure the required values
        have been supplied.
        """
        if self.__base_url is None:
            raise ValueError("Base URL must not be None")
        if self.__endpoint is None:
            raise ValueError("Endpoint must not be None")
        if self.__crypto is None:
            raise ValueError("PEM file must not be None")
        if self.__http_method is None:
            raise ValueError("HTTP method must be specified")

    def build(self):
        """
        Builds a SignedRequest object with the supplied values
        """
        self.__validate_request()

        endpoint = self.__endpoint + self.__append_query_params(self.__params)
        headers = self.__get_request_headers(
            endpoint, self.__http_method, self.__payload
        )
        url = self.__base_url + endpoint

        return SignedRequest(
            url, self.__http_method, self.__payload, headers, self.__request_handler
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/DocumentTypes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n compubapi_v1/DocumentTypes.proto\x12\x16yoti.core.compubapi_v1\"\xcc\x03\n\nIdDocument\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.yoti.core.compubapi_v1.IdDocument.Type\x12\x18\n\x10\x63ountry_iso_code\x18\x02 \x01(\t\"\xec\x02\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08PASSPORT\x10\x01\x12\x13\n\x0f\x44RIVING_LICENCE\x10\x02\x12\x0f\n\x0bNATIONAL_ID\x10\x03\x12\x0c\n\x08STATE_ID\x10\x04\x12\t\n\x05MYKAD\x10\x05\x12\x0b\n\x07\x41\x41\x44HAAR\x10\x06\x12\x07\n\x03PAN\x10\x07\x12\x0f\n\x0bSSS_ID_CARD\x10\x08\x12\r\n\tPOSTAL_ID\x10\t\x12\x14\n\x10RESIDENCE_PERMIT\x10\n\x12\x0c\n\x08VOTER_ID\x10\x0b\x12\x13\n\x0fPROFESSIONAL_ID\x10\x0c\x12\x0e\n\nNEXUS_CARD\x10\r\x12\x0f\n\x0bHEALTH_CARD\x10\x0e\x12\x0e\n\nPOSTOFFICE\x10\x0f\x12\x0e\n\nPHILSYS_ID\x10\x10\x12\x08\n\x04UMID\x10\x11\x12\x0f\n\x0b\x43ITIZENCARD\x10\x12\x12\r\n\tYOUNGSCOT\x10\x13\x12\x08\n\x04SCIS\x10\x14\x12\x13\n\x0fTRAVEL_DOCUMENT\x10\x15\x12\x0f\n\x0bWORK_PERMIT\x10\x16\"\x98\x05\n\x15SupplementaryDocument\x12@\n\x04type\x18\x01 \x01(\x0e\x32\x32.yoti.core.compubapi_v1.SupplementaryDocument.Type\x12\x18\n\x10\x63ountry_iso_code\x18\x02 \x01(\t\"\xa2\x04\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x10\n\x0cUTILITY_BILL\x10\x01\x12\x14\n\x10\x43OUNCIL_TAX_BILL\x10\x02\x12\x0e\n\nPHONE_BILL\x10\x03\x12\x12\n\x0e\x42\x41NK_STATEMENT\x10\x04\x12\x14\n\x10\x46IREARMS_LICENCE\x10\x05\x12\x11\n\rMILITARY_CARD\x10\x06\x12\x36\n2BIRTH_CERTIFICATE_ISSUED_WITHIN_12_MONTHS_OF_BIRTH\x10\x07\x12\x15\n\x11\x42IRTH_CERTIFICATE\x10\x08\x12\x18\n\x14\x41\x44OPTION_CERTIFICATE\x10\t\x12\x19\n\x15PAPER_DRIVING_LICENCE\x10\n\x12\x18\n\x14MARRIAGE_CERTIFICATE\x10\x0b\x12\x1a\n\x16\x41\x43\x43OUNT_OPENING_LETTER\x10\x0c\x12\x15\n\x11\x42\x45NEFIT_STATEMENT\x10\r\x12\x16\n\x12MORTGAGE_STATEMENT\x10\x0e\x12\x17\n\x13\x46INANCIAL_STATEMENT\x10\x0f\x12\x15\n\x11\x45MPLOYEE_TAX_FORM\x10\x10\x12!\n\x1d\x45MPLOYMENT_SPONSORSHIP_LETTER\x10\x11\x12\x18\n\x14IMMIGRATION_DOCUMENT\x10\x12\x12\x14\n\x10\x45\x44UCATION_LETTER\x10\x13\x12\r\n\tDVLA_FORM\x10\x14\x12\x1b\n\x17SUPPLEMENTARY_PASS_CARD\x10\x15\"l\n\x12IdDocumentSelector\x12\x15\n\rcountry_codes\x18\x01 \x03(\t\x12?\n\x0e\x64ocument_types\x18\x02 \x03(\x0e\x32\'.yoti.core.compubapi_v1.IdDocument.Type\"n\n\x1a\x44ocumentRestrictionsFilter\x12\x11\n\tallowlist\x18\x01 \x01(\x08\x12=\n\tdocuments\x18\x02 \x03(\x0b\x32*.yoti.core.compubapi_v1.IdDocumentSelectorBh\n\x15\x63om.yoti.compubapi_v1B\x12\x44ocumentTypesProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DocumentTypes_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\022DocumentTypesProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _IDDOCUMENT._serialized_start=61
  _IDDOCUMENT._serialized_end=521
  _IDDOCUMENT_TYPE._serialized_start=157
  _IDDOCUMENT_TYPE._serialized_end=521
  _SUPPLEMENTARYDOCUMENT._serialized_start=524
  _SUPPLEMENTARYDOCUMENT._serialized_end=1188
  _SUPPLEMENTARYDOCUMENT_TYPE._serialized_start=642
  _SUPPLEMENTARYDOCUMENT_TYPE._serialized_end=1188
  _IDDOCUMENTSELECTOR._serialized_start=1190
  _IDDOCUMENTSELECTOR._serialized_end=1298
  _DOCUMENTRESTRICTIONSFILTER._serialized_start=1300
  _DOCUMENTRESTRICTIONSFILTER._serialized_end=1410
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/IdentityProfileShare.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Policy_pb2 as sharepubapi__v1_dot_Policy__pb2
from . import Sharing_pb2 as sharepubapi__v1_dot_Sharing__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import DocumentTypes_pb2 as compubapi__v1_dot_DocumentTypes__pb2
from devicepubapi_v1 import StaticCredentialAuth_pb2 as devicepubapi__v1_dot_StaticCredentialAuth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)sharepubapi_v1/IdentityProfileShare.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1bsharepubapi_v1/Policy.proto\x1a\x1csharepubapi_v1/Sharing.proto\x1a\x1b\x63ompubapi_v1/Metadata.proto\x1a compubapi_v1/DocumentTypes.proto\x1a*devicepubapi_v1/StaticCredentialAuth.proto\"\xf9\x04\n\x0fNextStepRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12\x13\n\x0bwrapped_key\x18\x02 \x01(\x0c\x12\x16\n\x0e\x61uth_data_list\x18\x03 \x01(\x0c\x12\x30\n\x06policy\x18\x04 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.Policy\x12\x15\n\rsharing_token\x18\x05 \x01(\x0c\x12\x14\n\x0csession_data\x18\x06 \x01(\t\x12\x30\n\x06issuer\x18\x07 \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\x08 \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12!\n\x19user_profile_attribute_id\x18\t \x01(\x0c\x12M\n\x11unable_to_provide\x18\n \x01(\x0b\x32\x32.yoti.core.compubapi_v1.DocumentRestrictionsFilter\x12\x15\n\rattribute_ids\x18\x0b \x03(\x0c\x12\x14\n\x0creference_id\x18\x0c \x01(\t\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12\x16\n\rfeature_flags\x18\xc1\x0c \x01(\x06\x12\x17\n\x0e\x63orrelation_id\x18\xc2\x0c \x01(\t\x12P\n\x16static_credential_auth\x18\xb8\x17 \x01(\x0b\x32/.yoti.core.devicepubapi_v1.StaticCredentialAuth\"\xfc\x04\n\x10NextStepResponse\x12?\n\x05state\x18\x01 \x01(\x0e\x32\x30.yoti.core.sharepubapi_v1.NextStepResponse.State\x12?\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\x0b\x32\'.yoti.core.sharepubapi_v1.FailureReason\x12:\n\x0brequirement\x18\x03 \x01(\x0b\x32%.yoti.core.sharepubapi_v1.Requirement\x12\x43\n\x10progress_summary\x18\x04 \x01(\x0b\x32).yoti.core.sharepubapi_v1.ProgressSummary\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12\x46\n\x12unusable_documents\x18\x06 \x03(\x0b\x32*.yoti.core.sharepubapi_v1.UnusableDocument\x12m\n\x1esubsequent_next_step_may_abort\x18\x07 \x01(\x0e\x32\x45.yoti.core.sharepubapi_v1.NextStepResponse.SubsequentNextStepMayAbort\"V\n\x05State\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x12\x16\n\x12NEXT_STEP_REQUIRED\x10\x02\x12\x0c\n\x08\x44\x45\x41\x44_END\x10\x03\x12\x0e\n\nCALL_AGAIN\x10\x04\"E\n\x1aSubsequentNextStepMayAbort\x12\x12\n\x0eNOT_APPLICABLE\x10\x00\x12\t\n\x05\x46\x41LSE\x10\x01\x12\x08\n\x04TRUE\x10\x02\"\xc8\x01\n\x10UnusableDocument\x12\x34\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\".yoti.core.compubapi_v1.IdDocument\x12\x41\n\x06reason\x18\x02 \x01(\x0e\x32\x31.yoti.core.sharepubapi_v1.UnusableDocument.Reason\";\n\x06Reason\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07\x45XPIRED\x10\x01\x12\x15\n\x11OVERSEAS_PASSPORT\x10\x02\"\xde\x01\n\x0fProgressSummary\x12=\n\x0bproof_of_id\x18\x01 \x01(\x0b\x32(.yoti.core.sharepubapi_v1.CategoryStatus\x12\x42\n\x10proof_of_address\x18\x02 \x01(\x0b\x32(.yoti.core.sharepubapi_v1.CategoryStatus\x12H\n\x16\x62iometric_verification\x18\x03 \x01(\x0b\x32(.yoti.core.sharepubapi_v1.CategoryStatus\"$\n\rFailureReason\x12\x13\n\x0breason_code\x18\x01 \x01(\t\"\xf7\x01\n\x0e\x43\x61tegoryStatus\x12=\n\x05state\x18\x01 \x01(\x0e\x32..yoti.core.sharepubapi_v1.CategoryStatus.State\x12N\n\x16\x66ulfilled_requirements\x18\x02 \x03(\x0b\x32..yoti.core.sharepubapi_v1.FulfilledRequirement\"V\n\x05State\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x12\x0e\n\nTO_BE_DONE\x10\x02\x12\x0e\n\nNOT_NEEDED\x10\x03\x12\x14\n\x10NO_LONGER_NEEDED\x10\x04\"\x99\x01\n\x14\x46ulfilledRequirement\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.yoti.core.sharepubapi_v1.Requirement.Type\x12\x34\n\x08\x64ocument\x18\x02 \x01(\x0b\x32\".yoti.core.compubapi_v1.IdDocument\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"\xaf\x03\n\x0bRequirement\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.yoti.core.sharepubapi_v1.Requirement.Type\x12W\n\x14requirement_category\x18\x02 \x01(\x0e\x32\x39.yoti.core.sharepubapi_v1.Requirement.RequirementCategory\x12M\n\x15\x64ocument_restrictions\x18\x03 \x01(\x0b\x32..yoti.core.sharepubapi_v1.DocumentRestrictions\"R\n\x04Type\x12\x10\n\x0cUNDEFINED_RT\x10\x00\x12\x0f\n\x0bID_DOCUMENT\x10\x01\x12\x12\n\x0eMANUAL_ADDRESS\x10\x02\x12\x13\n\x0f\x43ONFIRM_ADDRESS\x10\x03\"j\n\x13RequirementCategory\x12\x10\n\x0cUNDEFINED_RC\x10\x00\x12\x0f\n\x0bPROOF_OF_ID\x10\x01\x12\x14\n\x10PROOF_OF_ADDRESS\x10\x02\x12\x1a\n\x16\x42IOMETRIC_VERIFICATION\x10\x03\"\x81\x01\n\x14\x44ocumentRestrictions\x12%\n\x1d\x63hip_verification_recommended\x18\x01 \x01(\x08\x12\x42\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x32.yoti.core.compubapi_v1.DocumentRestrictionsFilterBu\n\x17\x63om.yoti.sharepubapi_v1B\x19IdentityProfileShareProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IdentityProfileShare_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\031IdentityProfileShareProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _NEXTSTEPREQUEST._serialized_start=238
  _NEXTSTEPREQUEST._serialized_end=871
  _NEXTSTEPRESPONSE._serialized_start=874
  _NEXTSTEPRESPONSE._serialized_end=1510
  _NEXTSTEPRESPONSE_STATE._serialized_start=1353
  _NEXTSTEPRESPONSE_STATE._serialized_end=1439
  _NEXTSTEPRESPONSE_SUBSEQUENTNEXTSTEPMAYABORT._serialized_start=1441
  _NEXTSTEPRESPONSE_SUBSEQUENTNEXTSTEPMAYABORT._serialized_end=1510
  _UNUSABLEDOCUMENT._serialized_start=1513
  _UNUSABLEDOCUMENT._serialized_end=1713
  _UNUSABLEDOCUMENT_REASON._serialized_start=1654
  _UNUSABLEDOCUMENT_REASON._serialized_end=1713
  _PROGRESSSUMMARY._serialized_start=1716
  _PROGRESSSUMMARY._serialized_end=1938
  _FAILUREREASON._serialized_start=1940
  _FAILUREREASON._serialized_end=1976
  _CATEGORYSTATUS._serialized_start=1979
  _CATEGORYSTATUS._serialized_end=2226
  _CATEGORYSTATUS_STATE._serialized_start=2140
  _CATEGORYSTATUS_STATE._serialized_end=2226
  _FULFILLEDREQUIREMENT._serialized_start=2229
  _FULFILLEDREQUIREMENT._serialized_end=2382
  _REQUIREMENT._serialized_start=2385
  _REQUIREMENT._serialized_end=2816
  _REQUIREMENT_TYPE._serialized_start=2626
  _REQUIREMENT_TYPE._serialized_end=2708
  _REQUIREMENT_REQUIREMENTCATEGORY._serialized_start=2710
  _REQUIREMENT_REQUIREMENTCATEGORY._serialized_end=2816
  _DOCUMENTRESTRICTIONS._serialized_start=2819
  _DOCUMENTRESTRICTIONS._serialized_end=2948
# @@protoc_insertion_point(module_scope)



from yoti_python_sdk.doc_scan.constants import (
    DOCUMENT_RESTRICTIONS,
    INCLUSION_BLACKLIST,
    INCLUSION_WHITELIST,
)
from yoti_python_sdk.utils import YotiSerializable, remove_null_values
from .document_filter import DocumentFilter


class DocumentRestriction(YotiSerializable):
    def __init__(self, country_codes, document_types):
        self.__country_codes = country_codes
        self.__document_types = document_types

    @property
    def country_codes(self):
        return self.__country_codes

    @property
    def document_types(self):
        return self.__document_types

    def to_json(self):
        return remove_null_values(
            {
                "country_codes": self.country_codes,
                "document_types": self.document_types,
            }
        )


class DocumentRestrictionBuilder(object):
    def __init__(self):
        self.__country_codes = None
        self.__document_types = None

    def with_country_codes(self, country_codes):
        """
        Sets the list of country codes on the document restriction

        :param country_codes: the list of country codes
        :type country_codes: list[str]
        :return: the builder
        :rtype: DocumentRestrictionBuilder
        """
        self.__country_codes = country_codes
        return self

    def with_document_types(self, document_types):
        """
        Sets the list of document types on the document restriction

        :param document_types: the list of document types
        :type document_types: list[str]
        :return: the builder
        :rtype: DocumentRestrictionBuilder
        """
        self.__document_types = document_types
        return self

    def build(self):
        """
        Builds the document restriction using the values supplied to the builder

        :return: the document restriction
        :rtype: DocumentRestriction
        """
        return DocumentRestriction(self.__country_codes, self.__document_types)


class DocumentRestrictionsFilter(DocumentFilter):
    def __init__(self, inclusion, documents):
        DocumentFilter.__init__(self, DOCUMENT_RESTRICTIONS)

        self.__inclusion = inclusion
        self.__documents = documents

    @property
    def inclusion(self):
        return self.__inclusion

    @property
    def documents(self):
        return self.__documents

    def to_json(self):
        parent = DocumentFilter.to_json(self)
        parent["inclusion"] = self.inclusion
        parent["documents"] = self.documents
        return remove_null_values(parent)


class DocumentRestrictionsFilterBuilder(object):
    """
    Builder used to create a document restrictions filter.

    Example::

        document_restriction = (DocumentRestrictionBuilder()
                                .with_country_codes("GBR", "USA")
                                .with_document_types("PASSPORT")
                                .build())

        filter = (DocumentRestrictionsFilterBuilder()
                  .for_whitelist()
                  .with_document_restriction(document_restriction)
                  .build())
    """

    def __init__(self):
        self.__inclusion = None
        self.__documents = None

    def for_whitelist(self):
        """
        Sets the inclusion to whitelist the document restrictions

        :return: the builder
        :rtype: DocumentRestrictionsFilterBuilder
        """
        self.__inclusion = INCLUSION_WHITELIST
        return self

    def for_blacklist(self):
        """
        Sets the inclusion to blacklist the document restrictions

        :return: the builder
        :rtype: DocumentRestrictionsFilterBuilder
        """
        self.__inclusion = INCLUSION_BLACKLIST
        return self

    def with_document_restriction(self, document_restriction):
        """
        Adds a document restriction to the filter

        :param document_restriction: the document restriction
        :type document_restriction: DocumentRestriction
        :return: the builder
        :rtype: DocumentRestrictionsFilterBuilder
        """
        if self.__documents is None:
            self.__documents = []

        self.__documents.append(document_restriction)
        return self

    def build(self):
        """
        Builds the document restrictions filter, using the supplied values

        :return: the filter
        :rtype: DocumentRestrictionsFilter
        """
        return DocumentRestrictionsFilter(self.__inclusion, self.__documents)



from yoti_python_sdk.doc_scan.constants import ID_DOCUMENT
from yoti_python_sdk.utils import remove_null_values
from .document_filter import DocumentFilter  # noqa: F401
from .required_document import RequiredDocument


class RequiredIdDocument(RequiredDocument):
    def __init__(self, doc_filter=None):
        """
        :param doc_filter: the filter for the document
        :type doc_filter:
        """
        self.__doc_filter = doc_filter

    @property
    def type(self):
        return ID_DOCUMENT

    @property
    def filter(self):
        return self.__doc_filter

    def to_json(self):
        return remove_null_values({"type": self.type, "filter": self.__doc_filter})


class RequiredIdDocumentBuilder(object):
    """
    Builder used to assist the creation of a required identity document.

    Example::

        required_id_document = (RequiredIdDocumentBuilder()
                                .with_filter(some_filter)
                                .build())

    """

    def __init__(self):
        self.__id_document_filter = None

    def with_filter(self, id_document_filter):
        """
        Sets the filter on the required ID document

        :param id_document_filter: the filter
        :type id_document_filter: DocumentFilter
        :return: the builder
        :rtype: RequiredIdDocumentBuilder
        """
        self.__id_document_filter = id_document_filter
        return self

    def build(self):
        """
        Builds a required ID document, using the values supplied to the builder

        :return: the required ID document
        :rtype: RequiredIdDocument
        """
        return RequiredIdDocument(self.__id_document_filter)



from abc import ABCMeta
from abc import abstractmethod

from yoti_python_sdk.utils import YotiSerializable, remove_null_values


class RequestedTask(YotiSerializable):
    """
    Requests creation of a Task to be performed on each document
    """

    __metaclass__ = ABCMeta

    @property
    @abstractmethod
    def type(self):
        """
        Returns the type of the Task to create

        :return: the type
        :rtype: str
        """
        raise NotImplementedError

    @property
    @abstractmethod
    def config(self):
        """
        Configuration to apply to the Task

        :return: the configuration
        """
        raise NotImplementedError

    def to_json(self):
        return remove_null_values({"type": self.type, "config": self.config})



# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup

version = {}
with open("yoti_python_sdk/version.py") as fp:
    exec(fp.read(), version)

setup(
    name="yoti",
    version=version["__version__"],
    packages=find_packages(include=["yoti_python_sdk", "yoti_python_sdk.*"]),
    license="MIT",
    description="The Yoti Python SDK, providing API support for Login, Verify (2FA) and Age Verification.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/getyoti/yoti-python-sdk",
    author="Yoti",
    author_email="websdk@yoti.com",
    python_requires=">=3.9",
    install_requires=[


        "asn1==2.2.0",  # still pinned due to enum34 issue
        "cryptography>=42.0.0",
        "protobuf>=4.21.12",
        "requests>=2.31.0",
        "pyopenssl>=24.0.0",
        "pytz>=2025.2",
        "iso8601>=1.1.0",
        "deprecated>=1.2.14",

    ],
    extras_require={
        "examples": [
            "Django>=3.0.7",
            "Flask>=1.0.4",
            "python-dotenv>=0.7.1",
            "django-sslserver>=0.22.0",
            "Werkzeug==2.1.2",
        ],
        "dev": [
            "pre-commit==2.16.0",
            "pytest>=4.6.11",
            "pytest-cov>=2.7.1",
            "pylint==1.9.4",
            "pylint-exit>=1.1.0",
            "python-coveralls==2.9.3",
            "coverage>=7.4.0",
            "mock==2.0.0",
            "virtualenv==20.15.1",
            "flake8==4.0.1",
            "pip-tools==6.6.2",
        ],
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",

        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords="yoti sdk 2FA multifactor authentication verification identity login register verify 2Factor",
)



from .check.document_authenticity import RequestedDocumentAuthenticityCheckBuilder
from .check.face_match import RequestedFaceMatchCheckBuilder
from .check.liveness import RequestedLivenessCheckBuilder
from .notification_config import NotificationConfigBuilder
from .session_spec import SessionSpecBuilder
from .sdk_config import SdkConfigBuilder

__all__ = [
    "RequestedDocumentAuthenticityCheckBuilder",
    "RequestedFaceMatchCheckBuilder",
    "RequestedLivenessCheckBuilder",
    "NotificationConfigBuilder",
    "SessionSpecBuilder",
    "SdkConfigBuilder",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/Attribute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ttrpubapi_v1/Attribute.proto\x12\x17yoti.core.attrpubapi_v1\"\x9a\x01\n\nMultiValue\x12\x39\n\x06values\x18\x01 \x03(\x0b\x32).yoti.core.attrpubapi_v1.MultiValue.Value\x1aQ\n\x05Value\x12:\n\x0c\x63ontent_type\x18\x01 \x01(\x0e\x32$.yoti.core.attrpubapi_v1.ContentType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x9f\x02\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12:\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32$.yoti.core.attrpubapi_v1.ContentType\x12\x30\n\x07\x61nchors\x18\x04 \x03(\x0b\x32\x1f.yoti.core.attrpubapi_v1.Anchor\x12<\n\ruser_metadata\x18\x05 \x03(\x0b\x32%.yoti.core.attrpubapi_v1.UserMetadata\x12\x33\n\x08metadata\x18\x06 \x01(\x0b\x32!.yoti.core.attrpubapi_v1.Metadata\x12\x14\n\x0c\x65phemeral_id\x18\x07 \x01(\t\"\xa0\x01\n\x08Metadata\x12\x1d\n\x15superseded_time_stamp\x18\x01 \x01(\t\x12\x11\n\tdeletable\x18\x02 \x01(\x08\x12\x12\n\nreceipt_id\x18\x03 \x01(\x0c\x12\x0f\n\x07revoked\x18\x04 \x01(\x08\x12\x0e\n\x06locked\x18\x05 \x01(\x08\x12\x1c\n\x14\x65xtended_expiry_date\x18\x06 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x07 \x01(\x08\"\xb3\x01\n\x06\x41nchor\x12\x15\n\rartifact_link\x18\x01 \x01(\x0c\x12\x1b\n\x13origin_server_certs\x18\x02 \x03(\x0c\x12\x1a\n\x12\x61rtifact_signature\x18\x03 \x01(\x0c\x12\x10\n\x08sub_type\x18\x04 \x01(\t\x12\x11\n\tsignature\x18\x05 \x01(\x0c\x12\x19\n\x11signed_time_stamp\x18\x06 \x01(\x0c\x12\x19\n\x11\x61ssociated_source\x18\x07 \x01(\t\"*\n\x0cUserMetadata\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*u\n\x0b\x43ontentType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x08\n\x04JPEG\x10\x02\x12\x08\n\x04\x44\x41TE\x10\x03\x12\x07\n\x03PNG\x10\x04\x12\x08\n\x04JSON\x10\x05\x12\x0f\n\x0bMULTI_VALUE\x10\x06\x12\x07\n\x03INT\x10\x07\x12\n\n\x06JWT_VC\x10\x08\x42g\n\x16\x63om.yoti.attrpubapi_v1B\x0e\x41ttributeProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Attribute_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\016AttributeProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _CONTENTTYPE._serialized_start=894
  _CONTENTTYPE._serialized_end=1011
  _MULTIVALUE._serialized_start=59
  _MULTIVALUE._serialized_end=213
  _MULTIVALUE_VALUE._serialized_start=132
  _MULTIVALUE_VALUE._serialized_end=213
  _ATTRIBUTE._serialized_start=216
  _ATTRIBUTE._serialized_end=503
  _METADATA._serialized_start=506
  _METADATA._serialized_end=666
  _ANCHOR._serialized_start=669
  _ANCHOR._serialized_end=848
  _USERMETADATA._serialized_start=850
  _USERMETADATA._serialized_end=892
# @@protoc_insertion_point(module_scope)



import json


class DocScanException(Exception):
    """
    Exception thrown by the Yoti Doc Scan client
    when an error has occurred when communicating with the API
    """

    def __init__(self, message, response):
        """
        :param message: the exception message
        :type message: str
        :param response: the http response
        :type response: requests.Response
        """
        Exception.__init__(self)

        response_message = self.__get_response_message(response)

        self.__message = message + (
            " - " + response_message if response_message else ""
        )
        self.__response = response

    @property
    def message(self):
        """
        Get the specific exception message

        :return: the exception message
        :rtype: str
        """
        return self.__message

    @property
    def status_code(self):
        """
        Get the status code of the HTTP response

        :return: the status code
        :rtype: int or None
        """
        return self.__response.status_code

    @property
    def text(self):
        """
        Return the HTTP response body as text

        :return: the body as text
        :rtype: str
        """
        return self.__response.text

    @property
    def content(self):
        """
        Return the HTTP response body as bytes

        :return: the body as bytes
        :rtype: bytearray or None
        """
        return self.__response.content

    def __get_response_message(self, response):
        """
        Return the formatted response message

        :return: the formatted message
        :rtype: string or None
        """
        if response.headers.get("Content-Type") == "application/json":
            return self.__format_json_response_message(json.loads(response.text))

        return None

    def __format_json_response_message(self, parsed):
        """
        Return the formatted JSON response message

        :return: the formatted message
        :rtype: string or None
        """
        if not parsed.get("code") or not parsed.get("message"):
            return None

        code_message = parsed.get("code") + " - " + parsed.get("message")

        errors = []
        for error in parsed.get("errors", []):
            if error.get("property") and error.get("message"):
                errors.append(error.get("property") + ' "' + error.get("message") + '"')

        if len(errors) > 0:
            return code_message + ": " + ", ".join(errors)

        return code_message

    def __str__(self):
        return self.__message



from abc import ABCMeta
from abc import abstractmethod

from yoti_python_sdk.utils import YotiSerializable


class RequiredDocument(YotiSerializable):
    __metaclass__ = ABCMeta

    @property
    @abstractmethod
    def type(self):
        raise NotImplementedError

    def __new__(cls, *args, **kwargs):
        if cls is RequiredDocument:
            raise TypeError("RequiredDocument may not be instantiated")
        return object.__new__(cls)



from .document_restrictions_filter import (
    DocumentRestrictionBuilder,
    DocumentRestrictionsFilterBuilder,
)
from .orthogonal_restrictions_filter import OrthogonalRestrictionsFilterBuilder
from .required_id_document import RequiredIdDocumentBuilder
from .required_supplementary_document import RequiredSupplementaryDocumentBuilder

__all__ = [
    "DocumentRestrictionsFilterBuilder",
    "DocumentRestrictionBuilder",
    "OrthogonalRestrictionsFilterBuilder",
    "RequiredIdDocumentBuilder",
    "RequiredSupplementaryDocumentBuilder",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/AgeVerificationSecret.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*sharepubapi_v1/AgeVerificationSecret.proto\x12\x18yoti.core.sharepubapi_v1\"J\n\x15\x41geVerificationSecret\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x14\n\x0c\x62\x61nner_value\x18\x03 \x01(\x05\x42v\n\x17\x63om.yoti.sharepubapi_v1B\x1a\x41geVerificationSecretProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AgeVerificationSecret_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\032AgeVerificationSecretProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _AGEVERIFICATIONSECRET._serialized_start=72
  _AGEVERIFICATIONSECRET._serialized_end=146
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class WantedAttributeBuilder(object):
    """
    Builder for WantedAttribute
    """

    def __init__(self):
        self.__attribute = {}
        self.__constraints = []

    def with_name(self, name):
        """
        :param name: Sets name
        """
        self.__attribute["name"] = name
        return self

    def with_derivation(self, derivation):
        """
        :param derivation: Sets derivation
        """
        self.__attribute["derivation"] = derivation
        return self

    def with_accept_self_asserted(self, value=True):
        """
        :param value: True if self-asserted details are allowed
        """
        self.__attribute["accept_self_asserted"] = value
        return self

    def with_constraint(self, constraint):
        """
        :param constraint: Adds a constraint (e.g. a source constraint) to the
                            wanted attribute
        """
        if isinstance(constraint, list):
            self.__constraints.extend(constraint)
        else:
            self.__constraints.append(constraint)
        return self

    def build(self):
        """
        :return: The wanted attribute object
        """
        if self.__attribute.get("name", None) is None or self.__attribute["name"] == "":
            raise ValueError
        attribute = self.__attribute.copy()
        attribute["constraints"] = self.__constraints[:]
        return attribute



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/Signature.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63ompubapi_v1/Signature.proto\x12\x16yoti.core.compubapi_v1\"\xb0\x01\n\tSignature\x12\x39\n\x04\x61lgo\x18\x01 \x01(\x0e\x32+.yoti.core.compubapi_v1.Signature.Algorithm\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\"[\n\tAlgorithm\x12\r\n\tUNDEFINED\x10\x00\x12\x12\n\x0eRSA_PSS_SHA512\x10\x01\x12\x12\n\x0eRSA_PSS_SHA256\x10\x02\x12\x17\n\x13RSA_PKCS1V15_SHA256\x10\x03\x42\x64\n\x15\x63om.yoti.compubapi_v1B\x0eSignatureProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Signature_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\016SignatureProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _SIGNATURE._serialized_start=57
  _SIGNATURE._serialized_end=233
  _SIGNATURE_ALGORITHM._serialized_start=142
  _SIGNATURE_ALGORITHM._serialized_end=233
# @@protoc_insertion_point(module_scope)
